#include "gtk.h"
/* XPM */
static const char *const xpm_icon_0[] = {
/* columns rows colors chars-per-pixel */
"128 128 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.",
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.",
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.",
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.",
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.",
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.D.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.S.S.S.S.S.S.S.S.",
"S.S.S.S.S.S.S.S.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.F.A.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.V.C.A.S.D.C.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.A.S.S.S.S.S.S.S.",
"S.S.S.S.S.S.S.Z.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.n.K.T.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.U.I.U.E.Y.K.G.C.T.W.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.W.F.A.S.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.P T Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y T I ) *XBXxXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXcXcXvXNXcXuX*Xv.u.c.mXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXW.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.T Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q ! R ] %XbXhXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXvXhX:X`.y.@.Q -.S.lXUXPXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXPXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W Q T ' %XnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXzXxXzXsXoXJ.4._ Q U E K.W.hXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W Q T ' %XnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXxXcXgXwX!.k.=.W E R W W { $X.XdXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W Q T ' %XnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXbXyX,XL.8...Y T W W Q Q Y s.pX}.dXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W Q T ' %XnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXzXxXvX9X}.n.$.' Y T Q Q W W W E _ L.CX].fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W Q T ' %XnXjXlXlXlXlXlXlXlXlXlXlXlXjXlXcXlXhX,XI.f.} ! R R Q Q W W W W Q I 7.>XVX].fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W Q T ' %XnXjXlXlXlXlXlXlXlXlXlXkXzXbXkXyX@Xc.6.( T E E Q Q W W W W W W W ^ b.fXBX].fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W Q W W W W W W W W W W W W W W W W W Q T ' %XnXjXlXlXlXlXlXlXlXlXzXnXfX1X`.t.%.~ U W Q W W W W W W W W W ! U #.%XkXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXIXIXIXIXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W E Y Y Y Y T W W W W W W W W W W W W W Q T ' %XnXjXlXlXlXlXlXlXlXzXpXoXK.<.] R K Y T Y R W W W W W W W W W W Q u.tXzXMX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W E ^  .....X.{ W W W W W W W W W W W W W Q T ' %XnXjXlXlXlXlXlXkXxX8Xc.$.! E T ` o.X...X.` E W W W W W W W Q R ] ].kXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXIXMXxXcXxXcXHXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W ! L 4.M.t.a.u.C.) R W W W W W W W W W W W Q T ' %XnXjXlXlXlXlXlXlXzX!.} U W ! U l.j.i.i.j.l.I Q W W W W W W W W 5.1XbXhXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXDXH.oX|.+XI.3XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W ! K 7.*.A U S s.' T W W W W W W W W W W W Q T ' %XnXjXlXlXlXlXlXzXaXg.Y ! W Q I g.Q J J Q g.I Q W W W W W W W Q P.hXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXVX}.UXUXUXuX>XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W ! ! ~ P 7.1.Y ( R h.] E ! ! Q W W W W W W W W Q T ' %XnXjXlXlXlXlXkXvX.X&.R ~ ! ~ Y h.[ ! ! [ h.Y ~ ! ! Q W W Q T =.OXbXkXjXNX[.fXUXIXUXUXUXUXUXUXUXUXPXPXPXUXBX`.UXFXUX6X,XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W E L K P C 3.-.S Y D d.! H L K U Q W W W W W W W Q T ' %XnXjXlXlXlXlXlXhXG.W T K K P S d.~ K K ~ d.S P K K T Q W Q T c.aXzXlXjXNX[.fXUXIXUXUXUXUXUXUXUXIXUXUXUXUXLX{.UXUXUXyX>XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W E ^ 4.7.7.3.k.u.-.1.;.v.w.6.7.8.&.T Q W W W W W W Q T ' %XnXjXlXlXlXjXbX:X3.Y | 8.7.7.4.n.4.>.>.4.n.4.7.7.8.| T ! T O.^.cXlXlXjXNX[.fXUXIXUXUXUXUXUXUXIXUXiX:X,X1X&XE.eX7XtX}.3XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W Q Y  .M.*.1.-.u.I.L.L.P.F.1.>.:.6.c.I Q W W W W W W Q T ' %XnXjXlXlXlXlXkX(.' J 0.f.*.<.-.b.U.L.L.U.b.-.<.*.f.9.K ~ U 9.rXzXlXlXjXNX[.fXUXIXUXUXUXUXUXUXPXUXQ.1XqX0X6XC.v.b.m.j.0XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W Y ..t.A Y S -.L.V.Z.Z.S.R K K W f.U Q W W W W W W Q T ' %XnXjXlXlXkXvXqXr.~ K 8.%.S U D f.G.C.C.G.f.D U S %.8.L W ' J.hXzXlXlXjXNX[.fXUXIXUXUXUXUXUXUXPXUX].UXUXUXUXS.F.F.J.m.8XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W Y ..a.U ( Y 1.L.Z.S.S.S._ Q Q ' h.U Q W W W W W W Q T ' %XnXjXlXlXlXlX@XO.R P 8.,.Y / T j.H.A.A.H.j.T / Y ,.8.L E *.1XxXkXlXlXjXNX[.fXUXIXUXUXUXUXUXUXPXUX`.CXIXPXSXS.S.S.G.b.9XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W Y X.u.S R D ;.P.Z.S.S.S.E L L Q h.U Q W W W W W W Q T ' %XnXjXlXlXzXfXx.~ Q L 9.*.D T F f.J.A.A.J.f.F T D *.9.J / m.uXcXkXlXlXjXNX[.fXUXIXUXUXUXUXUXUXPXUX`.PXUXUXUXS.A.S.F.b.9XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W T { C.s.h.d.v.F.S.S.S.S.h.f.f.z.j.I Q W W W W W W Q T ' %XnXjXlXlXxX,X1.U ~ P 3.N.a.g.d.B.D.S.S.D.B.d.g.a.N.3.K  ..XvXkXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXPXUX).^.[.].`.S.S.S.F.b.9XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W ) ' ] ! w.1.R _ E h.o._ ' ' ^ W W W W W W W W Q T ' %XnXjXlXlXxXG.) E Q W ! ` ' ] / k.{ ~ ~ { k./ ] ' ` ! R s.8XcXkXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXHXCXCXSXlX`.UXSXUX5X<XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W R T E H 6.>.K Q L f._ U R T E W W W W W W W W Q T ' %XnXjXkXxX8Xp.U Q W W E R T E L g.) Y Y ) g.L E T R E ( R.cXkXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXSX].UXPXUXqX,XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W ! L 7.:.K Q L f.' R W W W W W W W W W W W Q T ' %XnXjXkXbX`.[ E W W W W W W ! U g.) Y Y ) g.U ! W ! U 7.>XcXkXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXCX[.UXIXUXqX,XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W ! K 8.6.W ' Q z.' T W W W W W W W W W W W Q T ' %XnXhXxXyXm.W W W W W W W W Q I k. ./ /  .k.I ! ! E ! m.jXlXlXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXCX^.PXCXUX1X:XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W Q U &.c.f.h.h.j.^ E W W W W W W W W W W W Q T ' %XnXgXbX=X@.E Q W W W W W W Q U w.l.g.g.l.w.T Q T E =.oXzXlXlXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXHX).`.`.].Q.iXUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W Q T I U U U I W W W W W W W W W W W W W Q T ' %XnXkXdXL.) R Q W W W W W W W W Y I U U U U U ! @.u.(.pXxXlXlXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W Q Q Q Q Q Q W W W W W W W W W W W W W Q T ' %XbXlX0X3.T Q W W W W W W W W W ! ! Q W R ` 4.z.OXeXlXxXlXlXlXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXPXPXPXPXPXIXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W Q T ' %XnXhX/...T Q W W W W W W W Q Q R R Q { d.L.1XgXlXcXlXkXlXlXlXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W Q T ' %XmXpXs.R Q W W W W W W Q Q T T ` #.M.[.7XcXxXzXlXkXlXlXlXlXlXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W Q T ' %XBX|.=.Y Q W W W W W W T T ..6.P.>XuXbXcXkXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W Q T ' %XbXZ.E W W Q Q W E R Q -.h.^.qXfXvXxXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W Q T ` ;X3X4.R Q ! E Y Q ) 4.F.oXdXlXxXzXjXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W Q T ` *X]./ W E I / +.i._.;XhXvXlXlXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.T ! Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q ! T | (.d.Y I ) 1.x.$XqXlXvXkXjXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXhXMX].dXUXPXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXPXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.I R T T T T T T T T T T T T T T T T T T T T T T T T T T T T T T R T T L { Y.$.o.l.Y.8XlXmXNXbXvXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXbXxXAX{.zXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXW.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.F.n.) ] ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ` '  .} :.V.j.S.#X6X5X5X3X3X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X2X4X7XiX).2XzXdXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXdXhXlXmXT.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.A.K.*X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X&X;X*XW.J.I.W.$XXX|.{.{.{.{.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.{.{.{.}.oX`.H.N.n.).{.].[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.].].].}..XW.A.c.C.D.S.S.S.S.S.S.",
"S.S.S.S.S.D.C.T.BXbXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXbXmXNXNXzX2X}.=XdXK.+XDXnXMXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXMXMXNXBXZXxX>X/.q.2.N.iXAXMXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXMXNXBXVXZXsX$XP.;.u.G.S.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.xXhXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXhXhXlXvXhX0XOX(.<XvXPXmXJ..XnXgXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXhXhXlXlXhXeX^.n.&.! T 8.J.7XxXhXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXhXjXzXkXgX1XP.f.| W W c.K.Z.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXmXsX:XXX|.9XJXUXUXUX%X.X XNXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXvXcXiX4XL.t.O.T E R Q ^.'.4XbXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXbXkXtX*Xm.8.` Y W U O.&XY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXcXbXtXOX X;XgXUXUXUXIXUXMXXX2X}.NXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXcX0X@Xn.;.] U T Q Q E #.:XOX2XnXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXbXkX3X[.i.$./ I E Q Q Q e.yXE.V.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXcXcXjX7X[.|.0XBXUXUXIXPXUXPXUX:X2X7X{.NXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXzXxXkX>X~.g...^ Y R Q Q W Q T v.lX|.3XnXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXzXxXxXsX@XI.8.[ Q U E ! W Q R _ (.xXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXkXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXnXcXtX:X[.@XlXKXUXUXIXPXUXUXIXUXDX XdX7X{.NXjXlXlXlXlXlXlXlXlXlXlXlXlXkXjXzXvXkXsX#XC.8.( W R E Q Q W W Q R X.!.ZX{.4XnXkXlXlXlXlXlXlXlXlXlXlXlXlXkXjXxXcXhXyX_.v.-.Q W R W ! W W W W E 3.:XNXI.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXkXlXlXlXlXlXlXlXlXlXlXlXkXlXnXzX4XoX.X>XMXUXUXUXUXIXUXUXUXUXPXUXrXXXNX4X}.NXjXlXlXlXlXlXlXlXlXlXlXlXkXzXnXfX7X].p.;.! Y W W Q Q W W W W Q U r.qXBX{.4XnXkXlXlXlXlXlXlXlXlXlXlXkXkXcXbXuX2XI.0.@.T T W W Q W W W W W W W G.gXvXU.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXkXlXlXlXlXlXlXlXlXkXzXxXcXfX=X`.$XyXJXUXUXIXUXUXUXUXUXUXUXUXUXPX$X4XCX3X}.NXjXlXlXlXlXlXlXlXlXkXlXzXbXpX&XY.3. .W U W Q W W W W W W W Q R ' H.hXNX{.4XnXkXlXlXlXlXlXlXlXlXlXlXcXcX0XoXB.*.] Y Y Q Q W W W W W W W Q T &..XvXcXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXkXlXlXlXlXlXlXlXlXcXkXeX+X_.2XzXKXUXIXKXIXUXUXUXUXUXUXUXUXIXUXvX'.zXbX4X}.NXjXlXlXlXlXlXlXlXzXxXzXqX(.M.*.) Q R ! ~ W W W W W W W W W ! Y -.2XlXMX}.4XnXkXlXlXlXlXlXlXlXxXxXkX,XR.g...( E E ~ ! W W W W W W W W W Q Y j.aXlXcXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXkXlXlXlXlXlXlXlXzX7XXX|.tXHXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUX<X;XbXbX4X}.NXjXlXlXlXlXlXlXzXhX<XJ.i.| R P H L P K U Q W W W W W W W W E ^ b.iXlXMX}.4XnXkXlXlXlXlXlXkXxXpX@XN.8.( R K J L L K T Q W W W W W W W Q T ..!.zXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXkXlXlXlXlXlXlXxXrX/.kXUXUXUXnX-X:X:X;X4XLXUXUXUXUXUXUXUXUXUXGX_.gXlXnX4X}.NXjXlXlXlXlXlXkXxX>X9.) U E T *.0.8.8.0.*.T Q W W W W W W Q R | +XcXhXNX}.4XnXkXlXlXlXlXlXkXzX).*.! U E ! 3.9.8.8.9.| T Q W W W W W W Q Y 6.qXxXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXkXlXlXlXlXlXkXnX.XaXUXPXLXUX>X].pX9XuXP.ZXUXUXUXUXUXUXUXIXUXqX@XvXkXnX4X}.NXjXlXlXlXlXlXlXzXG.) T ! ! I x.5.;.;.5.x.I ! W W W W W W W W a.8XvXhXNX}.4XnXkXlXlXlXlXkXcXrXu.R E ! R ` N.*.,.%.f.8.K ! W W W W W Q R ` G.fXzXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXkXlXlXlXlXlXzXsX].FXUXUXPXUX,XuXUXUXUX|.CXUXUXUXUXUXUXUXIXUX{.rXxXkXnX4X}.NXjXlXlXlXlXlXxX0Xu.U ! W Q I f.Q K K Q f.I Q W W W W W W W / Q.xXkXjXNX}.4XnXkXlXlXlXlXlXlX%X#.Y ! W T ' a.D Y S *.7.K ! W W W W W Q T #.>XcXkXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXkXlXlXlXlXkXmX%X4XUXPXPXKXUX>X7XUXGXUX'.BXUXPXPXIXUXUXPXUXfXXXkXzXkXnX4X}.NXjXlXlXlXlXkXbX).| E ! Q ~ Y h.] Q Q ] h.Y ~ Q ! Q W W Q Y 8.:XvXkXjXNX}.4XnXkXlXlXlXlXzXhXn.~ Q ! ! E ] g.T / U 1.7.K ! W W W W W E ! b.tXcXkXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXkXlXlXlXlXzXjX{.xXUXUXUXUXUX2XrXUXUXUX{.HXUXUXUXUXIXUXIXUX&X<XbXkXkXnX4X}.NXjXlXlXlXkXxXiXm.E T I I Y G f.~ L L ~ f.G Y I I T Q W W Q B.kXlXlXjXNX}.4XnXkXlXlXlXlXxX2X5.U T I U L / d.F T D -.7.K ! W W W W W E { {.vXkXlXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXkXlXlXlXkXnX4X#XUXZX/.].`.{.T.E.]._.].K.).].].(.&XUXPXUXmX|.sXxXlXkXnX4X}.NXjXlXlXlXjXnX$X%.P *.x.f.h.f.B.k.g.g.k.B.f.h.f.x.*.U ~ U =.oXxXlXlXjXNX}.4XnXkXlXlXlXkXcXP.' U w.k.g.g.k.B.f.j.d.B.1.P ! W W W W W T p.6XvXkXlXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXkXlXlXlXlXzX+XrXUXlX_.IXNXLX3Xx.V.N.M.Z.MXSXDXvX^.UXLXUX9X+XmXkXlXkXnX4X}.NXjXlXlXkXzXdXP.) J 0.5.Q ] ~ k.P.H.H.P.k.~ ] Q 5.0.K ~ R u.aXzXlXlXjXNX}.4XnXkXlXlXkXxX9Xd.T U l. .) ) { D.J.H.G.Y.,.P ! W W W W W ^ L.cXkXlXlXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXkXlXlXlXcXuX{.KXUXxXXXUXPXUX0Xb.H.D.D.S.KXUXUXGX'.UXUXJX XtXcXkXlXkXnX4X}.NXjXlXlXkXvX7X1.W L 8.;.K Q L g.H.Z.Z.H.g.L Q K ;.8.L R | ).jXlXlXlXjXNX}.4XnXkXlXlXkXbX}.| W U g./ Y Y ~ S.A.A.C.L.<.P ! W W W Q U 4.;XxXlXlXlXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXkXlXlXlXcX-X1XUXUXxXXXUXPXUX0Xb.H.D.D.S.KXUXUXGX'.UXUXhX[.bXkXlXlXkXnX4X}.NXjXlXlXlXkX_.| R L 8.;.K Q L g.H.Z.Z.H.g.L Q K ;.8.L W 1.7XvXkXlXlXjXNX}.4XnXkXlXkXxXiXB.Q Q U g./ Y Y ~ S.A.A.C.L.<.P ! W W W W Q x.hXzXlXlXlXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXkXlXlXlXkX_.ZXUXUXxX_.IXNXLX3Xx.V.N.M.Z.MXSXDXvX^.UXUX@X6XcXkXlXlXkXnX4X}.NXjXlXlXzXaXi.E ~ K 0.5.Q ] ~ k.P.H.H.P.k.~ ] Q 5.0.H ) P.dXzXkXlXlXjXNX}.4XnXkXlXjXvX>X&.E ! I l. .) ) { D.J.H.G.Y.,.P ! W W Q U $.oXlXlXlXlXlXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXkXlXkXvX3X&XUXIXUXAX/.].`.{.T.E.]._.].K.).].].(.%XUXNX'.kXlXlXlXlXkXnX4X}.NXjXlXlXxXoX=.U ~ U *.x.f.h.f.B.k.g.g.k.B.f.h.f.x.*.I %.$XnXjXlXlXlXjXNX}.4XnXkXkXzXfXI.` R ! Y w.k.g.g.k.B.f.j.d.B.1.P ! W W W W e.tXcXkXlXlXlXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXkXlXkXbX'.kXUXUXUXUXUXUXUXUX2XrXUXUXUX{.HXUXUXUXUXUX:X:XcXlXlXlXlXkXnX4X}.NXjXlXlXkXB.W W W Q T I I Y G f.~ L L ~ f.G Y I I T R n.iXxXkXlXlXlXjXNX}.4XnXkXkXxXwX6.T Q W W U I U L / d.F T D -.7.K ! W Q R ' (.jXlXlXlXlXlXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXkXkXvXwXoXJXUXUXUXUXPXPXKXUX>X7XUXGXUX'.BXUXPXLXUXHX}.uXcXlXlXlXlXkXnX4X}.NXjXkXvX:X7.Y Q W W Q ! Q ~ Y h.] Q Q ] h.Y ~ Q ! E | (.bXkXlXlXlXlXjXNX}.4XnXkXlXlX_.o.Y Q W W Q Q ! E ] g.T / U 1.7.K ! W W E ,.1XbXjXlXlXlXlXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXkXkXnXOX0XUXIXUXUXUXUXUXPXUX,XuXUXUXUX|.CXUXUXPXUXeX+XxXlXlXlXlXlXkXnX4X}.NXjXkXxXQ./ W W W W W W W Q I f.Q K K Q f.I Q W ! U u.0XxXlXlXlXlXlXjXNX}.4XnXkXlXdXj.T Q W W W W W W T ' a.D Y S *.7.K ! W Q Q J.dXzXkXlXlXlXlXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXkXcXaX XBXUXIXUXUXUXUXUXPXUX>X].pX9XuXP.ZXUXPXUXUX#X5XnXkXlXlXlXlXkXnX4X}.NXhXvX8Xp.W W W W W W W W ! I x.5.;.;.5.x.I ! ! Y _ G.lXlXlXlXlXlXlXjXNX}.4XnXjXvXOX;.Y Q W W W W W W R ` N.*.,.%.f.8.K ! Q U $..XnXkXlXlXlXlXlXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXkXvX<X*XUXPXUXUXUXUXUXUXIXUXnX;X:X:X;X3XPXUXUXPX1X[.lXlXlXlXlXlXlXkXnX4X}.NXhXcX+X| R Q W W W W W W Q T *.0.8.8.0.*.T E U _ 9.>XxXlXlXlXlXlXlXjXNX}.4XnXkXlXH.W W W W W W W W W E ! 3.9.8.8.0.| T R T | c.uXzXlXlXlXlXlXlXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vXlXkX XkXUXIXUXUXUXUXUXUXUXIXUXUXUXUXUXUXUXZX3X].@XiXxXkXlXlXlXlXlXkXnX4X}.MXlXpXb.^ E W W W W W W W W Q U K L L J P R [ t.F.:XhXzXlXlXlXlXlXlXjXNX}.4XbXvX<X8.R W W W W W W W W W W P K P K H Y W #.f.Q.8XzXlXlXlXlXlXlXlXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.cXzXeX}.UXIXUXUXUXUXUXUXUXUXUXPXKXUXUXDXdX*X).*XiXxXxXkXlXlXlXlXlXlXkXnX4X}.MXlX2X;.Y Q W W W W W W W W W ~ ~ E W ) $.b.~.6XlXxXzXlXlXlXlXlXlXlXjXNX}.4XbXlX'._ E W W W W W W W W W Q ~ ! R ! ' 2.D.[.uXzXxXlXlXlXlXlXlXlXlXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.cXvXoXyXUXIXUXUXUXUXUXUXUXIXIXUXUXBX7XXX[.4XzXcXxXlXlXlXlXlXlXlXlXlXkXnX4X{.NXhXH.' R Q W W W W W W W Q W U R } ,.K.$XuXbXxXlXlXlXlXlXlXlXlXlXlXjXNX}.3XNXwXa.Q W W W W W W W W W Q E U ! o.w./.:XhXbXzXlXkXlXlXlXlXlXlXlXlXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.U.vXsX'.HXUXUXUXUXUXUXIXUXUXUXUXjX$X X@XqXbXvXkXkXlXlXlXlXlXlXlXlXlXlXkXnX4X{.BX0Xr.U Q W W W W W Q W W Y Q =.y./.6XaXnXxXkXlXlXlXlXlXlXlXlXlXlXlXjXNX}.3XmX%XO.T Q W W W W Q Q W E U _ 1.k.+X0XjXnXlXkXlXlXlXlXlXlXlXlXlXlXlXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.I.BX&X4XUXUXUXUXUXPXUXUXUXFXuX}. X3XaXbXvXkXkXlXlXlXlXlXlXlXlXlXlXlXlXkXnX4X{.ZX~...R Q W W Q ! E R W ^ 3.N.XXaXjXvXzXjXkXlXlXlXlXlXlXlXlXlXlXlXlXjXNX{.5XlXb./ E Q W W Q Q R E W ' y.G.,XfXlXvXlXjXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.Y.vX].vXUXIXUXPXUXUXUXxX3X'.oXeXzXvXxXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX3X|.lXv.T Q W Q Q R Y ~ | i.Q.=XjXxXzXlXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNX{.5X0X2.I ! W Q Q T T ( @.b._.5XxXxXzXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.V.!.6X%XUXUXIXUXUXKXrX$X{.*XfXbXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX2XOX:X$.E Q Q R U ` =.l.XX8XxXvXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNX{.6XE.' E Q W Y T  .<.F.&XyXbXcXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.C.R.@XrXUXUXUXCX,X}.@X3XjXmXzXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbX4X'.~.! R E Y  .r.F.1XuXxXvXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX|.#Xl.U W R R *.s.~.9XaXbXxXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.D.Z.@XPXGXgX@X(.*XyXlXvXkXhXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXhXxX7XJ.7.U ! +.c.W.9XhXlXzXhXhXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXgXnXXXS.X.T ^ 1.C.[.iXjXzXlXhXhXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXhXxXY.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.S.C.#XdX#X.XqXbXNXNXnXbXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXbXVXtXN.3.8.~.;XkXZXBXBXMXMXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXnXDX$Xl.=.j.}.5XmXZXBXBXMXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXNXZXT.C.D.S.S.S.S.S.",
"S.S.S.S.S.S.A.G.T.G.].>X-X&X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X*XXXb.N.J.'.OX|.{.{.{.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.}.{.{.}. X.X+XQ.l.V.L.}..X[.].].[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.[.].{.H.A.S.S.S.S.S.S.",
"S.S.S.S.S.S.F.n.{ o.{ ` ` ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ' ] _ O.XXtX7X4X2X3X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X3X3X7X7X2X.XJ.P.Z.eXnXjXfXdXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXkXU.C.S.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.L T T T T T T T T T T T T T T T T T T T T T T T T T T T T T T T T T R U _ *XVXxXbXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXbXbXVXBXfX4XoX+XcXkXn.mXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXW.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.T ! Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q ! R ] %XbXhXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXvXxX6XXX|.;XmXUXUX2XS.lXUXPXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXPXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W Q T ' %XnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXzXxXvXgX:X`.$XwXAXUXUXUXbXXX{.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W Q T ' %XnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXxXbXkXtX$X`.<XvXLXUXUXPXIXUX1X3X.XdXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W Q T ' %XnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXxXmXfX1XoX{.8XDXUXUXUXPXIXUXUXKX).cX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W Q T ' %XnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXbXuX@X|.%XdXUXUXUXUXIXUXUXUXIXUXeXOXCX].fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W Q T ' %XnXjXlXlXlXlXlXlXlXlXlXkXlXcXcXlX8X{. X9XbXUXUXIXIXUXUXUXUXUXUXIXUX X9XCX].fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W Q T ' %XnXjXlXlXlXlXlXlXlXkXlXbXcXuX>X].XXfXHXUXUXIXPXUXUXUXUXUXUXUXIXUXjX.XgXBX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W Q Q Q Q Q Q W W W W W W W W W W W W W Q T ' %XnXjXlXlXlXlXlXlXkXxXzX6X@X|.;XmXUXUXUXPXPXUXUXUXUXUXUXUXUXUXIXUX;X:XvXMX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXPXPXPXPXPXIXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W Q T I U U U I W W W W W W W W W W W W W Q T ' %XnXjXlXlXlXlXlXlXxXuX}.%XeXGXUXUXUXUXUXUXUXIXUXUXUXUXUXUXUXIXUXBX|.aXlXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W Q U &.c.f.h.h.j.^ E W W W W W W W W W W W Q T ' %XnXjXlXlXlXlXlXlXxX@X1XUXUXUXUX%X^.'.'.^.&XUXIXUXUXUXUXUXUXIXUXeXXXmXhXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXHX).`.`.].Q.iXUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W ! K 8.6.W ' Q z.' T W W W W W W W W W W W Q T ' %XnXjXlXlXlXlXlXxXaX].PXUXPXLXUX(.vXGXGXvX(.UXPXUXUXUXUXUXUXUXKX.XeXcXhXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXCX^.PXCXUX1X:XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W ! L 7.:.K Q L f.' R W W W W W W W W W W W Q T ' %XnXjXlXlXlXlXlXcX:X,XUXPXUXPXUX].DXUXUXDX].UXPXUXUXUXUXUXUXUXlX].vXkXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXCX[.UXIXUXqX,XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W R T E H 6.>.K Q L f._ U R T E W W W W W W W W Q T ' %XnXjXlXlXlXlXlXzX_.VXUXUXUXUXUX].SXUXUXSX].UXUXUXUXUXUXUXIXUX#X5XcXkXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXSX].UXPXUXqX,XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W ) ' ] ! w.1.R _ E h.o._ ' ' ^ W W W W W W W W Q T ' %XnXjXlXlXlXkXvX5X$XUXPXZXCXBXHX).MXKXKXMX).HXBXCXZXLXUXIXUXCX'.hXzXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXHXCXCXSXlX`.UXSXUX5X<XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W T { C.s.h.d.v.F.S.S.S.S.h.f.f.z.j.I Q W W W W W W Q T ' %XnXjXlXlXlXkXbX[.sXUX3XP.|.'.{.K.Z.S.S.Z.K.{.'.|.P.4XUXKXUX1X-XcXlXlXjXNX[.fXUXIXUXUXUXUXUXUXPXUX).^.[.].`.S.S.S.F.b.9XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W Y X.u.S R D ;.P.Z.S.S.S.E L L Q h.U Q W W W W W W Q T ' %XnXjXlXlXkXvXeXXXDXUX;XuXUXUXUX].M.D.D.M.].UXUXUXuX;XUXIXJX XtXvXlXlXjXNX[.fXUXIXUXUXUXUXUXUXPXUX`.PXUXUXUXS.A.S.F.b.9XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W Y ..a.U ( Y 1.L.Z.S.S.S._ Q Q ' h.U Q W W W W W W Q T ' %XnXjXlXlXkXnX#X6XUXUX:X9XUXGXUX_.N.D.D.N._.UXGXUX9X:XUXUXyXXXxXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXPXUX`.CXIXPXSXS.S.S.G.b.9XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W Y ..t.A Y S -.L.V.Z.Z.S.R K K W f.U Q W W W W W W Q T ' %XnXjXlXlXxXsX XMXUXUX:XpXUXUXUX].V.H.H.V.].UXUXUXpX:XUXLX&X3XnXkXlXlXjXNX[.fXUXIXUXUXUXUXUXUXPXUX].UXUXUXUXS.F.F.J.m.8XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W Q Y  .M.*.1.-.u.I.L.L.P.F.1.>.:.6.c.I Q W W W W W W Q T ' %XnXjXlXlXvX3X#XUXKXUX;X].uX7XrXE.x.b.b.x.E.rX7XuX].-XUXcX].kXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXPXUXQ.1XqX0X6XC.v.b.m.j.0XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W E ^ 4.7.7.3.k.u.-.1.;.v.w.6.7.8.&.T Q W W W W W W Q T ' %XnXjXlXlXlX XhXUXPXUXnX>X,X>X2XT.3X0X0X3XT.2X>X,X>XnXUX3X&XmXkXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXIXUXiX:X,X1X&XE.eX7XtX}.3XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W E L K P C 3.-.S Y D d.! H L K U Q W W W W W W W Q T ' %XnXjXlXxXtX[.UXIXUXIXUXUXUXUXUX{.LXUXUXLX{.UXUXUXUXUXHX_.dXlXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXIXUXUXUXUXLX{.UXUXUXyX>XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W ! ! ~ P 7.1.Y ( R h.] E ! ! Q W W W W W W W W Q T ' %XnXjXkXbXOXrXUXIXUXUXIXPXPXKXUX`.NXPXPXNX`.UXKXPXLXUXyXOXcXkXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXPXPXPXUXBX`.UXFXUX6X,XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W ! K 7.*.A U S s.' T W W W W W W W W W W W Q T ' %XnXjXlXfX`.DXUXUXUXUXUXUXUXPXUX].IXUXUXIX].UXPXUXPXUX|.wXxXlXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXVX}.UXUXUXuX>XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W ! L 4.M.t.a.u.C.) R W W W W W W W W W W W Q T ' %XnXhXmX=X1XUXUXUXUXUXUXUXUXPXUX/._.XXXX_./.UXPXUXUXlX|.kXzXlXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXDXH.oX|.+XI.3XUXPXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W E ^  .....X.{ W W W W W W W W W W W W W Q T ' %XnXjXlX{.zXUXIXUXUXUXUXUXUXUXUXAXxXxXxXlXZXUXUXGXpX/.6XcXlXlXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXIXMXxXcXxXcXHXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W E Y Y Y Y T W W W W W W W W W W W W W Q T ' %XbXvX5X#XIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXcX7X[. XrXzXlXlXlXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W Q W W W W W W W W W W W W W W W W W Q T ' %XnXlX+XwXUXPXUXUXUXUXUXUXUXUXUXIXUXUXPXyX%X|.#XiXnXxXlXlXlXlXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXIXIXIXIXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W Q T ' %XNXyX{.HXUXIXUXUXUXUXUXIXIXUXUXUXSX4X[.XX3XjXmXxXkXlXlXlXlXlXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W Q T ' %XNX-X>XUXPXUXUXUXUXIXPXUXUXKXlX*X_.=XtXlXnXzXjXkXlXlXlXlXlXlXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W Q T ' %XnX_.BXUXUXUXUXIXIXUXUXVXqX+X].3XkXcXcXzXkXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W Q T ' =XeXOXUXIXIXUXUXUXUXcX=X.XOX9XvXvXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W Q T ` :XXXfXUXUXUXUXHXpX|.}.>XpXnXvXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.Y Q W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W W Q T { ].+XFXUXUXnX5X'.XXwXjXvXcXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNX[.fXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.T Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q ! T o.G.sXIXtX&X].#XaXvXzXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXhXNX].fXUXPXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXPXUXE.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.G.v.P T Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y Y T L { T.#X#X#X5XxXBXbXcXcXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXxXZX{.kXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXW.V.D.S.S.S.S.S.",
"S.S.S.S.S.S.S.Z.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.v.n.G.C.Z.R.!.Y.I.U.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.T.H.U.W.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.E.W.F.A.S.S.S.S.S.S.",
"S.S.S.S.S.S.S.S.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.G.F.A.S.D.C.V.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.A.C.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.V.A.S.S.S.S.S.S.S.",
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.D.S.S.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.S.S.S.S.S.S.S.S.",
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.",
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.",
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.",
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.",
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S."
};

/* XPM */
static const char *const xpm_icon_1[] = {
/* columns rows colors chars-per-pixel */
"96 96 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.",
"S.S.S.S.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.S.S.S.F.D.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.D.F.D.S.S.S.S.",
"S.S.S.F.K.J.J.J.J.J.J.J.J.J.J.J.J.J.J.J.J.J.J.J.J.J.J.J.J.J.J.J.G.V.B.B.B.B.B.B.B.B.B.B.B.B.B.B.B.B.B.B.B.B.B.B.B.B.N.N.Z.D.A.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.B.D.S.S.S.",
"S.S.F.M.i.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.a.i.k./.`._._._._._._._._._._._._._._._._._._._._.).)._.].[.Y.Z.K.XX|. X X X X X X X X X X X X X X X X X X X X X X X X|.XX(.Z.D.S.S.",
"S.A.K.i.G Y I I I I I I I I I I I I I I I I I I I I I I I I Y H +.dXNXbXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXbXbXbXmXBXnXwX(.e.<.{.UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXlXm.F.S.S.",
"S.A.J.a.Y ~ Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q ~ Y %.yXzXjXkXkXkXkXkXkXkXkXkXkXkXkXkXkXjXhXkXzXvXaX%Xb.*.W I j.XXUXLXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXLXUXsXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W W W W W W W W W W W W W W W W W Q U %.uXcXkXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXbXzXwX!.i.[ E Y E ] oX&XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W W W W W W W W W W W W W W W W W Q U %.uXcXkXlXlXlXlXlXlXlXlXlXlXkXkXcXvXhX=XG.>./ I R W ~ I t.yX@XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W W W W W W W W W W W W W W W W W Q U %.uXcXkXlXlXlXlXlXlXlXkXkXzXcXvXrX|.d.X.T Y E Q Q Q E ^ Q.zXoXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W W W W W W W W W W W W W W W W W Q U %.uXcXkXlXlXlXlXlXkXkXxXbXkX1XL.4.) Y T Q Q Q W W Q T =.0XlXoXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W W W Q Q Q Q W W W W W W W W W W Q U %.uXcXkXlXlXlXlXlXcXbXuXoXx.$.W T E Q Q W W W W W Q Y Z.zXhXOXUXIXUXUXUXUXUXUXUXUXUXUXIXIXIXIXIXUXUXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W W W U Y Y U R W W W W W W W W W Q U %.uXcXkXlXlXlXkXxX0XY.q._ U K T T Y W W W W W W Q T ..%XnXgXOXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W E ~ t.e.q.p...Y Q W W W W W W W Q U %.uXcXkXlXlXkXzXfXk.E Y I %.p.q.r.0.E W W W W W Q Y u.gXzXhXOXUXIXUXUXUXUXUXUXUXUXUXIX&X$X=X.XhXUXIXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W R ' t.Q W 1.:.P Q W W W W W W W Q U %.uXcXkXlXlXkXvX,X .T ^ P 6.%.Q / i.! W W W W W E ^ '.cXlXhXOXUXIXUXUXUXUXUXUXUXUXUXGXoXKXIXrX6XUXPXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W E R U ) 9.P L *.*.K E E W W W W W W Q U %.uXcXkXlXlXkXcXS.W E E K 2...P T w.E T R E W Q U 2.qXcXlXhXOXUXIXUXUXUXUXUXUXUXUXUXKX=XUXUXgX9XUXPXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W ~ ' ) X.w.E E :.1.^ ] ( W W W W W W Q U %.uXcXkXlXkXcXqX1.U _ ] ~ 9.+.W ~ y.] ` ` ! W W E F.vXkXzXhXOXUXIXUXUXUXUXUXUXLXCXAXnX#XIXUXiX9XUXPXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W Q U t.t.9.w.C.C.V.S.a.9.9.h.( E W W W W Q U %.uXcXkXlXkXvX_.W } j.8.8.h.S.B.Z.N.0.8.p.6.U R o.,XcXkXzXhXOXUXIXUXUXUXUXPXUX=XoX:X=XK.H.L.B.rXUXPXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W Q Y e.Q P E C.F.A.L.O.L K 9.' R W W W W Q U %.uXcXkXkXxXdXu.L O.2.J J ,.P.A.H.x.P P ' 8.I R h.gXzXkXzXhXOXUXIXUXUXUXUXPXUX=XGXUXUXU.V.D.b.tXUXPXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W Q Y q.W L E V.A.C.J.O.K J 8.' R W W W W Q U %.uXcXkXkXvX%X .L O.<.H H ,.K.V.F.x.P L ` 7.P ` }.bXkXlXzXhXOXUXIXUXUXUXUXPXUX;XHXUXUXY.A.J.M.rXUXPXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W Q U p.1.*.:.S.L.J.P.9.*.&.h._ R W W W W Q U %.uXcXkXkXxXN.T T X.d.%.&.u.I.J.P.N.*.&.7.w.G 0.yXxXkXlXzXhXOXUXIXUXUXUXUXPXUX@X3XiXtXH.b.N.l.tXUXPXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W R ..:.*.1.a.O.O.9.e.%.;.$.Q W W W W W Q U %.uXcXjXvX5X*.T W ~ *.;.$.p.2.O.@.f.;.=.:.[ W U.cXkXlXlXzXhXOXUXIXUXUXUXUXIXUXnXeXyX0X{.hXkX>X0XUXPXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W Y P K ^ 9.L K *.%.F U U W W W W W W Q U %.uXxXkXcXQ.! E Q E I U D <. .L U q.U P I I #.4XvXkXlXlXzXhXOXUXIXUXUXUXUXUXIXUXUXUXUX=XUXUXhX8XUXPXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W Q Q E ] 9.K J &.;.U ! Q W W W W W W Q U %.uXxXlXaX9.U Q W W Q ~ I 5.| K U e.~ Q ~ Y n.kXlXlXlXlXzXhXOXUXIXUXUXUXUXUXUXIXPXUXDX&XUXUXhX8XUXPXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W E ( h.9.8.h.$.U Q W W W W W W W Q U %.uXzXbX.X] R Q W W W Q I 1.s.8.w.d.Q E I ] XXnXkXlXlXlXzXhXOXUXIXUXUXUXUXUXUXUXUXUXLX].=X>X].rXUXPXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W W W ( ' ' _ Q W W W W W W W W W Q U %.uXcXgXv.Y Q W W W W W W Q ` ] ' ! I ( <.U.sXzXlXlXlXlXzXhXOXUXIXUXUXUXUXUXUXUXUXUXUXGXCXCXAXIXUXUXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W W W E R R R W W W W W W W W W W Q U %.yXnX3X+.T Q W W W W W Q Q R P T } d./.rXzXzXlXlXlXlXlXzXhXOXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W W W W W W W W W W W W W W W W W Q U %.yXmXJ.Q W W W W W Q Q R Y ! :.V.-XfXbXxXlXlXlXlXlXlXlXzXhXOXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W W W W W W W W W W W W W W W W W Q U $.aXyX6.U Q W Q Q W Y Y [ t.~.9XzXvXzXkXkXlXlXlXlXlXlXlXzXhXOXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W W W W W W W W W W W W W W W W W Q U $.sX.X^ W Q Q R Y W &.v.@XpXbXcXlXkXkXlXlXlXlXlXlXlXlXlXzXhXOXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W W W W W W W W W W W W W W W W W Q U &.rXh.R W T U ' 5.Y.3XzXvXxXkXkXlXlXlXlXlXlXlXlXlXlXlXlXzXhXOXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.Y ~ Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q ~ Y -.XXO.H W ..l.{.uXlXcXjXjXjXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXgXOXUXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXLXUXsXm.F.S.S.",
"S.A.J.i.H Y U U U U U U U U U U U U U U U U U U U U U U U U Y G -.M.' q.I.7XcXZXMXmXnXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXnXnXxX#XUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXlXm.F.S.S.",
"S.A.G.k.+.%.%.%.%.%.%.%.%.%.%.%.%.%.%.%.%.%.%.%.%.%.%.$.$.=.;.+.e.N.m.}.>X>X-X*X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X=X*X=X;X<X<X(.wX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X9X9XqXwXsX;XB.D.S.S.",
"S.D.V./.dXyXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXyXiXsXsX5X X|.Y.;XtX5X3X3X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X3X3X4X9X6X*XA.i.U.6X1X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X2X1X1X4X7X<X_.d.l.F.S.S.S.",
"S.D.B.`.NXzXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXcXxXxXbXMXzX0X%X:XdXCXK.qXNXvXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXbXbXbXMXBXnX6XQ.0.[ 2.'.BXbXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXbXmXNXVXfX%Xn.=.[ B.F.S.S.S.",
"S.D.B._.bXjXkXkXkXkXkXkXkXkXkXkXkXkXkXkXjXkXcXcXiX;X+X,XbXIXUXqX/.7XvXjXkXkXkXkXkXkXkXkXkXkXkXkXkXkXjXkXxXcXuXOXz.#.E U R R. XlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXjXjXlXbXjX6XY.q.) R H 2.OXC.D.S.S.",
"S.D.B._.nXkXlXlXlXlXlXlXlXlXlXlXlXkXkXzXbXlX0X$X%XyXDXUXUXUXSX-X%X5XnXkXlXlXlXlXlXlXlXlXlXlXlXkXkXzXvXzX8XQ.9.] Y T Q T *.1XoXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXvXcXfX#XN.$.~ I E Q E D.6XN.D.S.S.",
"S.D.B._.nXkXlXlXlXlXlXlXlXlXlXkXkXvXvXfX<X@X,XlXUXUXUXIXPXUXuX2X<X3XnXkXlXlXlXlXlXlXlXlXlXkXlXxXnXdX&XM.-.! Y R Q Q Q T b.kX}.zXlXlXlXlXlXlXlXlXlXlXkXkXzXcXvX9X(.r. .Y T E Q Q R { ,X9XM.D.S.S.",
"S.D.B._.nXkXlXlXlXlXlXlXlXkXzXvXcXwX=X@X0XZXUXUXUXIXIXUXUXUX$XhX:X4XnXkXlXlXlXlXlXlXkXkXlXbXzXeX/.a.{ R U W Q Q W Q T { $XxX}.zXlXlXlXlXlXlXlXlXkXkXxXbXfX:XA.<.~ Y T Q Q Q W Q U s.kX6XN.D.S.S.",
"S.D.B._.nXkXlXlXlXlXlXkXxXbXfX4XoX-XfXPXUXUXIXIXUXUXUXIXUXcX@XBX=X4XnXkXlXlXlXlXlXkXcXcXjX;XH.>.( U R W Q W W W W Q Y r.aXlX}.zXlXlXlXlXlXlXkXzXvXcXtX{.d.X.R Y E Q Q W W W Q R ) (.BX4XN.D.S.S.",
"S.D.B._.nXkXlXlXlXlXlXxXiX=X#X6XSXUXUXUXUXIXUXUXUXUXUXIXUX1X6XVX=X4XnXkXlXlXlXlXlXxXtX{.d.X.P L I E Q W W W W W W W ! ~.bXhX|.zXlXlXlXlXlXlXxXhX2XH.5.! L L Y W Q W W W W W Q Y ,.eXmX4XN.D.S.S.",
"S.D.B._.nXkXlXlXlXkXvX6X+XfXJXUXNXkXkXzXKXUXUXUXUXUXUXUXSX+XjXmX=X4XnXkXlXlXlXkXzX].2._ U ! o.O.O.[ E W W W W W Q U >.9XcXjX|.zXlXlXlXlXkXxXeXb.o.Q I [ O.O.o.^ E W W W W W Q R K.lXbX5XN.D.S.S.",
"S.D.B._.nXkXlXlXlXlXkXOXSXUXUXAX).5X8X[.uXUXPXUXUXUXIXUXeX>XvXnX=X4XnXkXlXlXkXcXrX<.L Q I 5.i.1.5.f.W W W W W W W E C.zXlXjX|.zXlXlXlXlXkXnX~.! Y E ^ j.3.<.a.>.P Q W W W Q T +.:XvXvX5XN.D.S.S.",
"S.D.B._.nXkXlXlXkXvX9X<XUXJXUXBX:XUXUXaXeXUXLXPXUXUXUXUX#XsXlXmX=X4XnXkXlXlXkXvX{.) Q ^ U 5.} J P w.~ Q ! Q W Q R } -XvXkXjX|.zXlXlXlXkXzXsXp.Y ^ W ) q.K J O.<.P Q W W W Q Y h.kXkXbX5XN.D.S.S.",
"S.D.B._.nXkXlXlXkXvX@XvXUXUXUXKX:XUXUXpXsXUXUXUXUXIXUXjX&XvXjXmX=X4XnXkXlXlXlXhXd.U I U S <.| J I q.U P P T Q Q I f.dXzXlXjX|.zXlXlXlXkXvX&X{ I P L E 0.L J O.<.P Q W W Q R _ .XcXjXbX5XN.D.S.S.",
"S.D.B._.nXkXlXlXcXyX&XUXaX,X5X;X_.9X0XOX.X7X1X7XPXUXUX>X0XvXjXmX=X4XnXkXlXkXbX=X..~ 5.5.<.f.q.,.1.k.5.3.7.o.R E _ _.bXkXlXjX|.zXlXlXlXlXzXM.Y @.7.3.7.k.<.>.u.>.I Q W W Q Y 8.tXcXjXbX5XN.D.S.S.",
"S.D.B._.nXkXlXkXvX:XyXUX XaXcXhXS.b.m.c.6XvXbX}.ZXUXCXOXxXkXkXmX=X4XnXkXlXlXlXF.P o.i.} | q.Y.J.I.m... .>.q.I R <.tXxXkXlXjX|.zXlXlXkXcX6X;.H y.=...o.V.I.J.T.-.I Q W W W W U.bXkXkXbX5XN.D.S.S.",
"S.D.B._.nXkXlXlXjXOXHXUX=XIXUXUXK.F.J.N.jXUXUX>XVXUX8X2XvXkXkXmX=X4XnXkXkXxXwX:.L O.1.J J ,.J.B.D.x.I P ' 6.I E L.zXlXlXlXjX|.zXlXlXkXvXW.! U 9./ P Y n.S.V.J.-.I Q W Q Y %.4XcXkXkXbX5XN.D.S.S.",
"S.D.B._.nXkXkXbX4X6XUXUX#XHXUXLXG.N.Z.v.fXUXUX&XZXIX#XdXxXlXkXmX=X4XnXkXkXbX~.( I O.5.P I 1.I.D.K.c.T Y } 0.J $.:XbXkXlXlXjX|.zXlXkXxXiX0.T U w.` T E M.J.D.I.-.I Q W W R v.kXzXlXkXbX5XN.D.S.S.",
"S.D.B._.nXkXlXxX#XmXUXUX-XXX&X+XP.!.~.P.].*X$X{.IXhX&XbXkXlXkXmX=X4XnXjXxXaXu.U R [ f.w.q.k.m.x.c.M.e.w.s.2.K k.kXlXlXlXlXjX|.zXlXkXvXoX] E Y 6.p.w.r.M.c.z.C.;.I Q Q E ] @XbXkXlXkXbX5XN.D.S.S.",
"S.D.B._.nXjXcXtX*XUXIXUXUXPXUXBX-XUXUXuXeXUXKXUXUX*XtXcXlXlXkXmX=X4XnXjXvX%X] R Q E W ~ U 5...I T e.~ Q ! T _ XXvXkXlXlXlXjX|.zXkXlXlXz.U Q W E Q W ) w.U P @.<.P Q ! I r.aXzXkXlXkXbX5XN.D.S.S.",
"S.D.B._.nXjXbX*XfXUXIXUXUXUXUXZX:XUXUXiXyXUXPXUXmX#XxXlXlXlXkXmX=X4XbXkXzXn.R W W W W Q P 3. .P Y w.Q E Q Y 8.yXcXkXlXlXlXjX|.zXjXbX<X#.T Q W W W R / q.I L +.,.P ! E ^ Q.vXkXlXlXkXbX5XN.D.S.S.",
"S.D.B._.bXlXfX@XKXUXUXUXUXUXUXZX XVXZX,XwXUXLXUX6X4XbXkXlXlXkXmX=X4XbXcX5X=.U Q W W W ! P 7.>.' } s.! Q W E Y.bXkXlXlXlXlXjX|.zXkXxXI.E W W W W W E / a.[ ` 3.2.I ^ U *.0XcXkXlXlXkXbX5XN.D.S.S.",
"S.D.B._.bXvX2X9XUXIXUXUXUXUXUXLX<X:X,X&XVXUXUXfXXXjXzXlXlXlXkXmX=X4XbXcXE.W W W W W W Q T o.q.6.0.2.T Y E 4.4XcXkXlXlXlXlXjX|.zXzXuX3.Y Q W W W W W W 4.9.7.w.| I Y _ G.kXlXlXlXlXkXbX5XN.D.S.S.",
"S.D.B._.nXkX+XCXUXIXUXUXUXUXUXUXUXUXUXUXHXuX%X$XiXxXkXlXlXlXkXmX=X3XMXuX9.Y Q W W W W W Q R I I J K _ 5.I.3XlXlXlXlXlXlXlXjX|.lXbX]._ R Q W W W W W W U I P G R X.l.}.pXzXkXlXlXlXkXbX5XN.D.S.S.",
"S.D.B.).NX0X:XUXIXUXUXUXUXIXIXUXUXUXbX<X@X;XiXvXxXlXlXlXlXlXkXmX=X3XBXXX' R Q W W W W Q Q E R E @.j..XrXvXvXlXlXlXlXlXlXlXjX}.cXfXh.U Q W W W W W Q Q R R / 6.H.1XfXnXzXlXlXlXlXlXkXbX5XN.D.S.S.",
"S.D.B.).VX#XlXUXIXUXUXIXIXUXUXKXpX-XOX6XjXnXxXkXlXlXlXlXlXlXkXmX=X4XbXk.Y Q W W W Q W R U ) ,.J.-XkXvXcXkXkXlXlXlXlXlXlXlXjX}.bX:X .R Q W W Q Q E Y R ..a.'.wXcXvXzXkXlXlXlXlXlXlXkXbX5XN.D.S.S.",
"S.D.B.'.hX#XIXUXIXIXUXUXUXBX9X@X;XtXvXvXzXkXlXlXlXlXlXlXlXlXkXmX*X9X5X+.T Q Q Q W U E { a.).tXzXbXlXkXkXlXlXlXlXlXlXlXlXlXjX}.vXZ.W W Q Q Q R Y ~ ;.C.-XfXbXxXkXkXkXlXlXlXlXlXlXlXkXbX5XN.D.S.S.",
"S.D.N.{.5XqXUXLXUXUXIXjX;X@X2XgXbXcXkXkXlXlXlXlXlXlXlXlXlXlXkXmX=X6XE.E Q Q T Y Q ;.B.=XsXbXxXlXkXlXlXlXlXlXlXlXlXlXlXlXlXjXXXwX<.U ~ E T Y [ e./.8XxXvXzXkXkXlXlXlXlXlXlXlXlXlXlXkXbX5XN.D.S.S.",
"S.D.B._.$XSXUXUXZXwX#X%XwXxXbXzXkXkXlXlXlXlXlXlXlXlXlXlXlXlXkXnX;X*X9.U T Y [ e.Q.6XzXvXzXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXoX`.~ E I ~ $.M.oXsXcXvXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXkXbX5XN.D.S.S.",
"S.S.S.D.eXUXlX:XoX>XsXcXxXjXjXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXhXvX,XZ.` R &.c.@XaXbXcXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlX_.e.I ` 0.U.7XlXnXxXlXlXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXlXnX5XN.D.S.S.",
"S.S.A.F.5X3X-XuXnXCXMXnXnXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXbXZX6Xu.2.T.<XkXxXzXhXhXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXxXnXT.,.d. XeXzXlXhXgXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXgXxX3XN.D.S.S.",
"S.S.D.C.s.k.S.Z.B.N.N.B.B.B.B.B.B.B.B.B.B.B.B.B.B.B.B.B.B.B.B.B.V.R.`. XoX}.}.}.|.|.|.|.|.|.|.|.|.|.|.|.|.|.|.}.}. XoX.XR.Y.P.]..X%X@XoXoXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOXOX#X'.C.D.S.S.",
"S.A.K.i.J Y K L L L L L L L L L L L L L L L L L L L L L L L I F O.dXnXlXlXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXvXmXhX6XOX3X@X).UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXgXm.F.S.S.",
"S.A.J.a.U ~ ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ~ T &.yXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXvXxXyX*X+X6XVXUX-X_.UXPXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W W W W W W W W W W W W W W W W W Q U %.uXcXkXlXlXlXlXlXlXlXlXlXlXlXlXkXlXxXbXkX7X#X*XaXHXUXUXvXXX%XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W W W W W W W W W W W W W W W W W Q U %.uXcXkXlXlXlXlXlXlXlXlXlXlXkXlXvXvXaX:X+X2XmXUXUXUXLXUX<X6X$XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W W W W W W W W W W W W W W W W W Q U %.uXcXkXlXlXlXlXlXlXlXkXkXxXbXzX9X%X$XuXDXUXUXIXIXIXUXAX@XgX+XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W W W W W W W W W W W W W W W W W Q U %.uXcXkXlXlXlXlXlXkXlXcXbXsX1XOX1XkXUXUXUXIXIXUXUXIXUXeX,XxXoXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W W W Q Q Q Q W W W W W W W W W W Q U %.uXcXkXlXlXlXlXlXcXxXeX%X#X7XZXUXUXUXIXUXUXUXUXUXUXIX#XdXkXOXUXIXUXUXUXUXUXUXUXUXUXUXPXPXPXPXIXUXUXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W W W I U U I R W W W W W W W W W Q U %.uXcXkXlXlXlXkXxXqX@X:XhXUXUXUXUXUXUXUXUXUXUXUXIXUXkX%XbXgXOXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W E ! 0.q.9.t.| T Q W W W W W W W Q U %.uXcXkXlXlXlXxXpXXXBXUXUXhXOX;X&X1XUXUXUXUXUXUXIXUX:XwXvXhXOXUXIXUXUXUXUXUXUXUXUXUXUX:X*X;X@XzXUXIXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W R ` u.( ^ 4.;.P Q W W W W W W W Q U %.uXcXkXlXlXkXnX=XaXUXKXUX,XtXGXZX.XPXUXUXUXUXIXUXBX+XzXzXhXOXUXIXUXUXUXUXUXUXUXUXUXGX.XDXHX9X6XUXPXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W E Y _ 9.P L *.=.L W E W W W W W W Q U %.uXcXkXlXlXzXgX@XGXUXIXUX5XcXUXUX&XUXUXUXUXUXIXUX9X1XbXlXhXOXUXIXUXUXUXUXUXUXUXUXUXJX=XUXUXgX9XUXPXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W Q / ~ } q.Y U -.,.E ) ! W W W W W W Q U %.uXcXkXlXkXvX5X4XUXJXDXUX,XlXUXUX#XDXGXHXUXUXUXLX+XgXzXzXhXOXUXIXUXUXUXUXUXUXUXGXJXVX%XUXUXsX9XUXPXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W Q U w.u.q.r.V.m.n.C.d.0.w.g./ E W W W W Q U %.uXcXkXlXkXcXOXZXVX_.=X=X).J.Y.I.I.&X=X|.3XUXUXsX=XvXkXzXhXOXUXIXUXUXUXUXPXUX:X.X=X%XL.U.R.A.rXUXPXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W Q Y e.~ U Q C.G.D.L.+.P L 0.' R W W W W Q U %.uXcXkXkXvXeX-XUXkX3XUXUX8Xv.S.M.Q.UXUXNX;XUXUX-XrXcXkXzXhXOXUXIXUXUXUXUXPXUX*XDXUXUXU.N.S.v.tXUXPXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W Q Y q.Q P E V.A.V.J.O.K K 8.' R W W W W Q U %.uXcXkXkXvX=XsXUXkX7XUXUX9XM.K.Z.~.UXUXCX,XUXnX+XcXkXlXzXhXOXUXIXUXUXUXUXPXUX;XHXUXUXY.S.J.M.rXUXPXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W Q U p.;.@.&.S.P.K.I.5.+.+.f._ R W W W W Q U %.uXcXkXzXfX@XLXUXlX|.kXjX#Xx.M.c.I.gXhX4X&XUX1X6XvXkXlXzXhXOXUXIXUXUXUXUXPXUX@X9XgXdXH.v.M.l.tXUXPXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W Q R +.2.>.5.f.&.&.e.y.;.1.-.Q W W W W W Q U %.uXcXjXbX<X0XUXUXHX0X7XrX}.,XiXtX_.7X9X5XnXKX+XhXzXlXlXzXhXOXUXIXUXUXUXUXIXUXzX6X0X4X'.uXpX&XqXUXPXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W Y P K ~ 8.K J &.$.D I I W W W W W W Q U %.uXcXkXzX+XVXUXIXUXUXUXUX8XvXUXUX*XUXUXUXUXuX-XnXkXlXlXzXhXOXUXIXUXUXUXUXUXIXUXUXUXUX=XUXUXjX8XUXPXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W Q ! E ] 9.J H %.;.U ~ Q W W W W W W Q U %.uXxXcXqX:XUXIXUXUXPXKXUX2XnXUXUX%XKXPXLXUX%XiXxXlXlXlXzXhXOXUXIXUXUXUXUXUXUXIXPXUXDX*XUXUXkX8XUXPXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W R ( j.6.4.g.&.I Q W W W W W W W Q U %.uXxXvX%XlXUXIXUXUXUXPXUX5X X2X;X].IXUXUXlX#XvXkXlXlXlXzXhXOXUXIXUXUXUXUXUXUXUXUXUXLX`.>X2X{.wXUXPXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W W W ' | } { ! W W W W W W W W W Q U %.uXvXpX$XIXUXUXUXUXUXUXUXKXmXbXnXHXUXAXwX.XyXxXlXlXlXlXzXhXOXUXIXUXUXUXUXUXUXUXUXUXUXZXnXnXMXLXUXUXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W W W R Y Y T W W W W W W W W W W Q U %.yXMX:XrXUXIXUXUXUXUXUXIXUXUXUXUXbX,X+X,XgXxXlXlXlXlXlXzXhXOXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W W W W W W W W W W W W W W W W W Q U %.iXzXOXSXUXIXUXUXUXIXIXUXUXFXrX$X#XqXkXbXzXkXlXlXlXlXlXzXhXOXUXIXUXUXUXUXUXUXUXUXUXUXUXIXIXIXUXUXUXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W W W W W W W W W W W W W W W W W Q U $.sXqX<XUXIXUXIXIXUXUXUXbX4XOX>XiXbXcXlXkXlXlXlXlXlXlXlXzXhXOXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W W W W W W W W W W W W W W W W W Q U $.sX%XvXUXIXIXUXUXJXsX*X#X6XkXbXcXkXkXlXlXlXlXlXlXlXlXlXzXhXOXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.I Q W W W W W W W W W W W W W W W W W W W W W W W W Q U =.6X-XPXUXUXUXBX8X@X=XyXxXbXlXkXlXlXlXlXlXlXlXlXlXlXlXlXzXhXOXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXUXdXm.F.S.S.",
"S.A.J.a.U ! Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q ! Y -.XXsXUXJXgX*X@X2XdXvXzXkXjXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXgXOXUXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXLXUXsXm.F.S.S.",
"S.A.J.i.H Y U U U U U U U U U U U U U U U U U U U U U U U U Y H @.|.DXtX-X-XiXmXBXnXvXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXbXnXxX#XUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXkXm.F.S.S.",
"S.A.H.k.o.$.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.#.$.o.8.!.Q.[.>X0X8X5X4X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X5X3X'.gXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXsXkX1XB.D.S.S.",
"S.S.S.F.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.H.Z.C.Z.V.M.N.N.N.N.N.N.N.N.N.N.N.N.N.N.N.N.N.N.N.N.N.N.N.N.C.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.B.D.S.S.S.",
"S.S.S.S.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.S.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.D.S.S.S.S.",
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.",
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S."
};

/* XPM */
static const char *const xpm_icon_2[] = {
/* columns rows colors chars-per-pixel */
"88 88 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.",
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.S.S.S.S.",
"S.S.S.S.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.S.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.C.Z.S.S.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.S.S.S.S.",
"S.S.S.A.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.n.A.I.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.L.L.P.R.I.F.F.Y.U.U.U.U.U.U.U.U.U.U.U.U.U.U.U.U.U.U.U.U.U.U.U.U.U.D.S.S.S.",
"S.S.F.m.Q W Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q ! L M.mXjXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXjXjXxXvXgX=Xm.4.[.UXPXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXUXIXU.C.D.S.",
"S.S.F.m.W E W W W W W W W W W W W W W W W W W W W W W W ! K M.MXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXzXvXbXrX`.u.} P e.@XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W W W W W W W W W W W W W W W ! L M.mXjXlXlXlXlXlXlXlXlXlXlXlXkXkXxXnXkX<XD.,.~ U T / '.>XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W W W W W W W W W W W W W W W ! L M.mXjXlXlXlXlXlXlXlXlXkXkXlXvXbXpX}.j...T U E ~ Y 2.eX=XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W W W W W W W W W W W W W W W ! L M.mXjXlXlXlXlXlXlXkXkXzXbXzX4XT.4./ I T Q Q Q W R L.lX%XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W W Q Q Q Q W W W W W W W W W ! L M.mXjXlXlXlXlXlXlXcXbXsX$Xc.#.E Y E Q Q W W Q T o.2XzX$XUXIXUXUXUXUXUXUXUXUXUXIXIXIXIXUXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W W Y I U U W W W W W W W W W ! L M.mXjXlXlXlXlXzXzXqXW.q.^ J J Y Q Q W W W W Q U k.zXgX%XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W E ..$.$.O.Q W W W W W W W W ! L M.mXjXlXlXlXlXjXU.#.Q I ..%.%.o.W W W W W Q E ) oXbXgX%XUXIXUXUXUXUXUXUXUXUXIXjXdXsXcXUXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W ! a.-.&.a.[ T W W W W W W W ! L M.mXjXlXlXkXvX4X..P E _ s.*.*.s.( R W W W Q U 8.pXcXgX%XUXIXUXUXUXUXUXUXIXUXBX|.pXrX XPXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W R ~ 6.L G <.{ Y W W W W W W W ! L M.mXjXlXlXkXvXP.E Q R _ 4.J J 4._ T W W W W W T.bXkXhX%XUXIXUXUXUXUXUXUXUXUXMX8XUXUX,XJXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W E ! ~ ) 9.R I 3. .W ~ E W W W W W ! L M.mXjXlXkXxXuX4.I ^ ! ] 7.Y Y 7.] ! ! E Q T $.8XcXlXhX%XUXIXUXUXUXUXUXUXKXIXcX4XUXUX:XJXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W Q Y ..a.6.9.m.v.c.N.e.6.i.=.U Q W W W ! L M.mXjXlXkXbX|.W @.a.6.q.M.v.v.M.q.6.p.@.T Y m.zXlXlXhX%XUXIXUXUXUXPXUXyXXX1X%XP.Q.T.^.UXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W Q I $.-.L R v.K.G.S.( L X.1.P Q W W W ! L M.mXjXlXlXkXf.H :.$.L ! B.H.H.B.! L $.:.K [ $XnXjXzXhX%XUXIXUXUXUXPXUX7XzXUXFXS.V.M.E.UXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W Q U $.&.G I c.G.S.A.~ G } <.I Q W W W ! L M.mXjXkXbX>XX.K ;.O.G R N.D.D.N.R G O.;.H r.fXzXlXzXhX%XUXIXUXUXUXPXUX8XmXUXLXF.S.C.W.UXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W Q U O.a.<.3.N.S.A.A.7.<.y.>.I Q W W W ! L M.mXjXkXcXF.R U &.i.<.5.C.A.A.C.5.<.i.&.U ).bXkXlXzXhX%XUXIXUXUXUXPXUX0X+X8X>XF.F.Z.W.UXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W Q [ {  .e.( ~ 7.%.' { ~ E W W W W ! L M.mXjXxXrX;.Y Q ! [ [ O.q.^ ^ q.O.[ } T -.wXcXkXlXzXhX%XUXIXUXUXUXUXUXKXMXVXaX>XLXFX*XKXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W T Y W 6.L G <.' P T E W W W W W ! L M.mXhXnX(.~ E Q E T U / 3.J J 3./ U R T Z.cXkXlXlXzXhX%XUXIXUXUXUXUXUXUXUXUXVX8XUXUX<XJXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W ~ i.X.} y.{ T Q W W W W W W ! L M.mXlXfXy.I ! W W Q E _ u. . .i.` W Y [ :XbXkXlXlXzXhX%XUXIXUXUXUXUXUXUXIXUXMX+XmXzXXXLXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W E =.1.<.>.~ E W W W W W W W ! L M.nXcX=X] R Q W W W W Q ;.1.2.:.T Y ) m.gXzXlXlXlXzXhX%XUXIXUXUXUXUXUXUXUXUXKX0X8X7XyXUXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W W U P I I E W W W W W W W W ! L M.nXzXM.Y Q W W W W W Q Y L H P #.c.#XsXzXlXlXlXlXzXhX%XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W W Q Q Q Q W W W W W W W W W ! L m.VX6X&.Y Q W W W Q W T Y _ 6.E.7XzXbXzXlXlXlXlXlXzXhX%XUXIXUXUXUXUXUXUXUXUXUXPXPXPXPXUXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W W W W W W W W W W W W W W W ! L m.CXE.W W W Q Q E U T X.l..XpXbXvXlXkXlXlXlXlXlXlXzXhX%XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W W W W W W W W W W W W W W W ! K N.zX7.U ! Q T U ~ 1.G.1XlXnXxXkXkXlXlXlXlXlXlXlXlXzXhX%XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W W W W W W W W W W W W W W W ! J A.=X_ R Y Y | u.'.tXbXvXlXkXkXlXlXlXlXlXlXlXlXlXlXzXhX%XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ~ P M.n.G ! *.C.-XjXvXxXjXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXfX%XUXPXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXPXU.C.D.S.",
"S.S.F.n.L K L L L L L L L L L L L L L L L L L L L L K K U J f.5.0.(.eXvXmXxXzXzXxXxXxXxXxXxXxXxXxXxXxXxXzXzXlXcXzX*XUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXY.C.D.S.",
"S.S.S.A.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.m.M.C.Z.k.p.Z.W.[.%X+XoX.XoXoXoXoXoXoXoXoXoXoXoXoXoXoXXXXXOX%X.X/.R.*X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X$X%X*X:X@X[.F.S.S.S.",
"S.S.Z.I.mXMXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXnXNXCXMXpX,X4X5XQ.bXkXhXhXjXjXjXjXjXjXjXjXjXjXjXjXjXjXhXjXxXxXiX Xd.>./.zXfXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXgXgXgXzXlXrX].r.4.F.S.S.S.",
"S.S.Z.P.jXkXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXzXcXsX1X@X1XxXUX7X!.zXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXbXcX7XR.6._ L s..XcXlXzXzXzXzXzXzXzXzXzXzXzXzXlXlXkXcXbXxX4XI.3.( P n.I.Z.S.S.",
"S.S.Z.P.kXlXlXlXlXlXlXlXlXlXlXlXlXkXzXbXxXtX-X*XrXAXUXUXZX%X+XjXlXlXlXlXlXlXlXlXlXlXlXlXkXkXcXnXfX$Xv.$.E U R ) |.%XlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXcXnXaXOXl.+.R U T [ *XR.C.S.S.",
"S.S.Z.P.kXlXlXlXlXlXlXlXlXlXkXkXcXbXjX6X%X>XkXUXUXUXLXUXwX5X#XjXlXlXlXlXlXlXlXlXlXkXkXzXbXcXwX~.t.' U Y W ~ U 5.uXOXzXlXlXlXlXlXlXlXlXlXkXkXzXbXxX9XR.0.) U T W ~ U y.fXI.C.S.S.",
"S.S.Z.P.kXlXlXlXlXlXlXlXkXzXvXvXuX>X%X0XCXUXUXUXIXUXUXPX&XhXOXjXlXlXlXlXlXlXlXkXkXxXbXjX;XS.-.Q I R Q Q Q W E T.xXXXzXlXlXlXlXlXlXlXkXkXcXbXgX&XB.%.W I E Q Q Q E ! ).vXL.Z.S.S.",
"S.S.Z.P.kXlXlXlXlXlXlXzXbXjX9X$X=XdXJXUXUXIXIXUXUXIXUXhX-XnXXXjXlXlXlXlXlXlXlXvXvXyX{.a. .T Y W ! Q W W Q Y #.5XxXXXxXlXlXlXlXlXlXzXvXcXeX`.t.{ Y T W ! Q W W Q U :.eXxXL.Z.S.S.",
"S.S.Z.P.kXlXlXlXlXlXzXgX<X&X6XAXUXUXUXIXIXUXUXUXUXIXUX>XtXvXoXjXlXlXlXlXlXzXjX2XH.1.R H K Y Q W W W W W Q U c.xXjXoXxXlXlXlXlXlXzXhX,XA.:.Y H K T Q W W W W W Q T S.vXjXP.Z.S.S.",
"S.S.Z.P.kXlXlXlXlXzXhX+XpXGXUXkXeXeXiXPXUXUXUXUXIXUXBX%XxXzXoXjXlXlXlXlXlXhXD.| R U $.:.;.$.W W W W W Q R ` #XbXhXoXxXlXlXlXlXzXdXM.[ T T &.;.:.@.E W W W W Q T | ,XvXjXP.Z.S.S.",
"S.S.Z.P.kXlXlXlXkXbX1XtXUXUXJX XdXkXXXNXUXIXUXUXIXUX8X7XvXzXoXjXlXlXlXkXvX1X} U W _ a.@.+.p.) R W W W ! I w.sXxXjXoXxXlXlXlXkXbX%X) Y R } i.O.$.p.! E W W W Q I f.hXzXkXP.Z.S.S.",
"S.S.Z.P.kXlXlXlXlXlX%XDXUXUXPX<XUXUX8XBXUXUXUXUXUXJX%XjXlXxXoXjXlXlXlXkXvXG.R W Y ( 3.J J 3.( Y R W W W Q !.nXkXjXoXxXlXlXlXlXxXm.Y W U [ <.G L 6.^ E W W Q E / {.nXkXkXP.Z.S.S.",
"S.S.Z.P.kXlXlXkXvXqX3XUXSXSXBX=XPXUX1XjXGXSXIXIXUXsX>XbXkXxXoXjXlXlXkXxXtX<.U _ ( | 9.E E 9.| ( ) W Q Y *.qXcXlXjXoXxXlXlXkXcX8X%.T ` / O.5.R ! 0.~ E W W Q Y 2.iXxXlXkXP.Z.S.S.",
"S.S.Z.P.kXlXlXkXvX%XBXbX}.3X,XI.K.P.J.=X4XoXeXUXUX-XpXxXkXxXoXjXlXlXkXbX].T $.a.3.9.B.N.N.B.9.3.p.$.Y Y C.xXlXlXjXoXxXlXlXkXbXW.P :.i.3.q.C.N.C.x.E W W W Q T I.vXkXlXkXP.Z.S.S.",
"S.S.Z.P.kXlXlXxXpX=XUXsXuXUXUXW.B.Z.D.JXUXvX6XUXcX*XvXkXlXxXoXjXlXlXzXhXi.H :.@.J E N.G.G.N.E J +.;.K | =XbXkXlXjXoXxXlXkXxXaX8.H 2. .J ^ A.D.H.v.R W W Q Y +.3XvXkXlXkXP.Z.S.S.",
"S.S.Z.P.kXlXkXbX,XiXUXaXuXUXUXW.B.Z.D.JXUXvX6XUX3X9XvXkXlXxXoXjXlXkXbX=X| K ;.+.J E N.G.G.N.E J @.:.H p.hXzXlXlXjXoXxXlXkXbXoX` L 1. .J ^ A.D.H.v.R W W Q Y z.zXlXlXlXkXP.Z.S.S.",
"S.S.Z.P.kXlXlXkX%XGXUXlX|.3X,XI.K.P.J.=X4XoXrXUX@XlXlXlXlXxXoXjXlXlXxXC.T Y $.p.3.9.B.N.N.B.9.3.a.$.R ].bXkXlXlXjXoXxXkXlXlXl.Y Y ;.u.3.q.C.N.C.x.E W Q E ) +XbXkXlXlXkXP.Z.S.S.",
"S.S.Z.P.kXlXvX7X7XUXIXUXFXSXBX=XPXUX1XjXGXZXUXyX1XbXkXlXlXxXoXjXlXcXqX&.Y Q W ) ( | 9.E E 9.| ( _ U ,.tXxXkXlXlXjXoXxXkXvX3XX.T Q Q _ / O.5.R ! 0.~ E ! I 0.aXxXkXlXlXkXP.Z.S.S.",
"S.S.Z.P.kXlXcX%XNXUXIXUXUXUXPX<XUXUX8XBXUXUXUX=XsXxXlXlXlXxXoXjXkXnX!.Q W W W R Y ( 3.J J 3.( Y W R G.vXkXlXlXlXjXoXxXjXbXJ.R W W W E U [ <.G L 6.^ W Q Q E.bXkXlXlXlXkXP.Z.S.S.",
"S.S.Z.P.kXcXyX:XUXIXUXUXUXUXLX.XdXkXXXmXUXUXxX*XbXkXlXlXlXxXoXjXxXsXw.I ! W W W R ) p.+.@.a._ W U } <XvXkXlXlXlXjXoXzXxXyX2.U Q W W Q T [ i.O.$.a.^ Q P @.9XcXkXlXlXlXkXP.Z.S.S.",
"S.S.Z.P.kXbX:XgXUXIXUXUXUXUXUXfXwXeXaXUXIXkX+XuXxXlXlXlXlXxXoXhXbX$X` R Q W W W W W $.;.:.$.U R } D.hXlXlXlXlXlXjXoXzXvX{.~ E W W W W E ! &.;.:.@.I E ..U.lXlXlXlXlXlXkXP.Z.S.S.",
"S.S.Z.P.lXhX%XLXUXUXUXUXUXUXIXUXUXUXLXrX&X=XpXxXlXlXlXlXlXxXoXjXxXv.U Q W W W W W Q Y K H T >.A.,XhXzXlXlXlXlXlXjXoXxXjXa.U Q W W W W Q Q Y K H W 2.H.3XjXzXlXlXlXlXlXkXP.Z.S.S.",
"S.S.Z.L.vX4XqXUXIXUXUXIXIXUXUXIXzX<X@X4XdXbXxXlXlXlXlXlXlXxXXXxX5X#.Y Q W W Q ! W T Y } y.'.rXvXvXlXlXlXlXlXlXlXjXXXmX;X| T Q W W Q ! E Y T ..s.}.uXvXvXlXlXlXlXlXlXlXkXP.Z.S.S.",
"S.S.Z.P.zX%XCXUXIXIXIXUXUXGXiX=X=XqXzXbXzXkXlXlXlXlXlXlXlXzXXXxXY.E W W Q Q E I W &.V.*XgXbXcXkXkXlXlXlXlXlXlXlXjXoXvXA.Y Q W Q Q R I ! ;.D.:XjXbXxXkXkXlXlXlXlXlXlXlXkXP.Z.S.S.",
"S.S.Z.Y.rX<XUXLXUXUXUXmX6X$X<XsXvXvXlXkXlXlXlXlXlXlXlXlXlXzXOXiX5.U ~ W Y U _ q.W.9XxXbXzXkXkXlXlXlXlXlXlXlXlXlXhX+XtX-.Y ! W Y Y ' y.^.eXcXbXzXkXkXlXlXlXlXlXlXlXlXlXkXP.Z.S.S.",
"S.S.C.R.*XlXUXUXJXfX;X&X9XkXbXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlX%X|._ R U E @.z.OXsXnXcXlXkXlXlXlXlXlXlXlXlXlXlXlXlXhX%X_.~ R U W %.b.%XfXnXxXkXkXlXlXlXlXlXlXlXlXlXlXlXlXkXP.Z.S.S.",
"S.S.S.S.;XUXBX7X#X;XuXzXcXkXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXlX.Xa.K ( 4.U.5XxXbXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkX{.e.K ` 8.W.8XcXbXxXkXlXzXzXzXzXzXzXzXzXzXzXzXzXzXzXlXP.Z.S.S.",
"S.S.D.C.,XwX:XeXvXCXNXmXnXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXnXZX_.:.a.}.yXxXxXjXhXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXzXnXT.*.g. XuXzXzXgXgXgXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXgXL.Z.S.S.",
"S.S.S.A.d.f.V.Z.N.m.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.M.N.m.D._..X%X+XXXXXoXoXoXoXoXoXoXoXoXoXoXoXoXoXXXOX#X+X~.R.U.|.$X>X*X%X$X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X%X&X%XH.A.S.S.",
"S.S.F.n.Y U K K L L L L L L L L L L L L L L L L L L L L I Z m.ZXzXlXzXzXxXxXxXxXxXxXxXxXxXxXxXxXzXzXvXmXjX6X%X7X=X].UXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXY.C.D.S.",
"S.S.F.m.! Q ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ^ I N.nXjXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXvXxXyX;X$XqXZXUX;X|.UXPXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W W W W W W W W W W W W W W W ! L M.mXjXlXlXlXlXlXlXlXlXlXlXkXkXxXbXjX8X&X>XgXLXUXUXbX@X;XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W W W W W W W W W W W W W W W ! L M.mXjXlXlXlXlXlXlXlXlXkXlXvXvXaX,X%X6XNXUXUXUXLXUX4X8X-XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W W W W W W W W W W W W W W W ! L M.mXjXlXlXlXlXlXlXkXxXbXzX0X=X=XpXJXUXUXIXIXUXUXDX%XhX&XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W W Q Q Q Q W W W W W W W W W ! L M.mXjXlXlXlXlXlXxXbXsX2X@X1XcXUXUXUXIXIXUXUXIXUXtX2XxX%XUXIXUXUXUXUXUXUXUXUXUXPXPXPXPXUXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W W U P I I E W W W W W W W W ! L M.mXjXlXlXlXlXxXiX=X=XtXIXUXUXUXIXUXUXUXUXUXUXUX*XfXjX%XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W E =.1.<.>.~ E W W W W W W W ! L M.mXjXlXlXlXxXpX+XcXUXUXtX6X6XeXIXUXUXUXUXIXUXlX=XbXgX%XUXIXUXUXUXUXUXUXUXUXKX0X8X7XyXUXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W ~ i.X.} y.{ T Q W W W W W W ! L M.mXjXlXlXkXbX-XjXUXUXZXoXvXvXoXSXUXIXUXUXIXUX<XrXvXgX%XUXIXUXUXUXUXUXUXIXUXMX+XmXzXXXLXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W T Y W 6.L G <.' P T E W W W W W ! L M.mXjXlXlXzXfX&XPXUXUXGX4XUXUX4XGXUXUXUXIXUXCX%XxXzXhX%XUXIXUXUXUXUXUXUXUXUXVX8XUXUX<XJXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W Q [ {  .e.( ~ 7.%.' { ~ E W W W W ! L M.mXjXlXkXbX4XwXUXmXBXjX=XJXJX=XjXBXNXPXIXUXqX4XbXlXhX%XUXIXUXUXUXUXUXKXMXVXaX>XLXFX*XKXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W Q U O.a.<.3.N.S.A.A.7.<.y.>.I Q W W W ! L M.mXjXlXlXzX#XKXsXXX8X1XJ.D.D.J.1X8XXXiXUXKX%XhXzXzXhX%XUXIXUXUXUXPXUX0X+X8X>XF.F.Z.W.UXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W Q U $.&.G I c.G.S.A.~ G } <.I Q W W W ! L M.mXjXlXcXeX<XUXrXkXUXUXP.Z.Z.P.UXUXkXeXUXdX:XbXkXzXhX%XUXIXUXUXUXPXUX8XmXUXLXF.S.C.W.UXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W Q I $.-.L R v.K.G.S.( L X.1.P Q W W W ! L M.mXjXkXvX=XlXUXwXdXUXPXK.B.B.K.PXUXdXeXUX;XyXcXlXzXhX%XUXIXUXUXUXPXUX7XzXUXFXS.V.M.E.UXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W Q Y ..a.6.9.m.v.c.N.e.6.i.=.U Q W W W ! L M.mXjXxXsX*XIXUXfX.X<X=XI.W.W.I.=X<X XkXSX$XcXkXlXzXhX%XUXIXUXUXUXPXUXyXXX1X%XP.Q.T.^.UXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W E ! ~ ) 9.R I 3. .W ~ E W W W W W ! L M.mXjXbX1XyXUXIXUXLXPXBX,XUXUX,XBXPXJXUX6X8XvXkXlXzXhX%XUXIXUXUXUXUXUXUXKXIXcX4XUXUX:XJXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W R ~ 6.L G <.{ Y W W W W W W W ! L M.mXkXlX$XFXUXUXUXUXUXSX3XUXUX3XSXUXUXHX%XjXzXlXlXzXhX%XUXIXUXUXUXUXUXUXUXUXMX8XUXUX,XJXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W ! a.-.&.a.[ T W W W W W W W ! L M.nXcX0X4XUXIXUXUXUXUXFX|.uXuX}.SXUXUXpX>XbXkXlXlXzXhX%XUXIXUXUXUXUXUXUXIXUXBX|.pXrX XPXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W E ..$.$.O.Q W W W W W W W W ! L M.mXxX*XnXUXIXUXUXUXUXUXlXaXsXvXUXFXtXOXfXzXlXlXlXzXhX%XUXIXUXUXUXUXUXUXUXUXIXjXdXsXcXUXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W W Y I U U W W W W W W W W W ! L M.NXuX-XUXIXUXUXUXUXIXIXUXUXUXVX5X$X<XhXzXlXlXlXlXzXhX%XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W W Q Q Q Q W W W W W W W W W ! L m.CX;XsXUXIXUXUXIXIXUXUXGXaX*X%XqXkXbXzXlXlXlXlXlXzXhX%XUXIXUXUXUXUXUXUXUXUXUXIXIXIXIXUXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W W W W W W W W W W W W W W W ! L N.bX$XJXUXIXIXUXUXUXBX8X%X,XiXvXvXlXkXlXlXlXlXlXlXzXhX%XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W W W W W W W W W W W W W W W ! K Z.rX6XUXLXUXUXIXhX>X%X7XkXbXxXkXkXlXlXlXlXlXlXlXlXzXhX%XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.Q W W W W W W W W W W W W W W W W W W W W W W W ! K C.:XNXUXUXZXeX%X-XyXcXvXlXkXlXlXlXlXlXlXlXlXlXlXlXzXhX%XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXU.C.D.S.",
"S.S.F.m.W E W W W W W W W W W W W W W W W W W W W W W W Q U f.wXUXxX<X$X4XgXbXcXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXhX&XUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXU.C.D.S.",
"S.S.F.m.Q W Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q Q ! Y d.,X:X&XeXzXvXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXgX%XUXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXIXUXIXU.C.D.S.",
"S.S.S.A.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.n.A.C.S.R.Y.P.L.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.P.L.H.Y.U.U.U.U.U.U.U.U.U.U.U.U.U.U.U.U.U.U.U.U.U.U.U.U.U.D.S.S.S.",
"S.S.S.S.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.S.D.S.C.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.A.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.S.S.S.S.",
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.S.S.S.S.",
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S."
};

/* XPM */
static const char *const xpm_icon_3[] = {
/* columns rows colors chars-per-pixel */
"64 64 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.",
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.A.S.D.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.S.S.S.S.",
"S.S.S.S.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.S.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.C.V.A.A.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.S.S.S.S.",
"S.S.S.A.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.n.A.I.P.P.P.P.P.P.P.P.P.P.P.P.L.L.R.Q.G.G.T.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.D.S.S.S.",
"S.S.F.m.~ Q ! Q Q Q Q Q Q Q Q Q Q Q Q Q ~ L v.mXhXkXkXkXkXkXkXkXkXjXhXkXbXcX5XF.>.@XUXKXPXPXPXPXPXPXPXPXPXPXPXPXPXPXIXKXY.C.D.S.",
"S.S.F.m.Q E W W W W W W W W W W W W W W ! J v.NXkXlXlXlXlXzXlXkXkXvXMXhXOXg.} F 8.0XUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXY.C.D.S.",
"S.S.F.m.! W W W W W W W W W W W W W W W ! K v.NXjXlXlXlXkXjXlXnXnXwXT.2.W L R W ].tXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXPXY.C.D.S.",
"S.S.F.m.Q W W W W W W W Q Q Q W W W W W ! J v.NXjXlXlXkXxXMXzX=Xv.X.I I W ~ U :.iX9XUXIXUXUXUXUXUXIXIXIXUXUXUXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.Q W W W W W W E T T T W W W W W ! J v.NXjXlXkXxXuX/.6.Q H U ! Q W ! P L.vX6XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.Q W W W W Q E ] <.,.@.R Q W W W ! J v.NXjXkXvX9X-.L ' ,.1...R Q Q T { 8XlX6XUXIXUXUXUXPXUXgX0X8XVXUXIXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.Q W W W W E K X...Q ;.L T W W W ! J v.NXjXjXMXL.G P &.` ` %.K R ! L g.nXfX7XUXIXUXUXUXUXUXrXPXcXhXUXIXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.Q W W W E ] X.<.-...6.X...W W W ! J v.NXhXzXdX-.` o.4.#.#.4.X.} E Q @XMXfX7XUXIXUXUXUXcXzX,XxXrXlXUXIXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.Q W W Q T <...-.G.K.t.` 4./ E W ! J v.NXgXmX|.R 4.[ 5.J.J.5.[ 5.I 2.hXxXgX7XUXIXUXUXHX2XZX@Xm.B.xXUXIXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.Q W W Q T ,.Q ..K.Y.9.K >.( R W ! J v.NXhXcXi.P 2.U ;.I.I.;.U 1.U R.MXkXgX7XUXIXUXUXFX0XUX;Xz.m.xXUXIXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.Q W W Q T @.;.6.t.9.t.=.;.Q W W ! J v.MXcX2X` T *.=.q.w.w.q.-.#. .eXcXlXgX7XUXIXUXUXIXeXyX@X:XOXzXUXIXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.Q W W W W R L X.` K =.I T W W W ! J v.mXbXZ.L ! R L $.W W $.U J v.nXkXzXgX7XUXIXUXUXUXUXUXyXUXZXjXUXIXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.Q W W W W Q T ..4.>.;.T ! W W W ! J c.VXyX$.U Q ! T $.3.3.@.G / -XnXkXzXgX7XUXIXUXUXUXPXUXeX0X2XvXUXIXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.Q W W W W W W W / ( Q W W W W W ! J x.DX(.Y Q W Q ! Q Q R ' u.oXlXlXlXzXgX7XUXIXUXUXUXUXUXIXFXHXUXUXUXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.Q W W W W W W W E R W W W W W W ! J v.BX8.P ~ ! E P T #.Z.3XcXnXlXlXlXzXgX7XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.Q W W W W W W W W W W W W W W W ! H B.5X^ W T L ( q.`.pXmXbXkXjXlXlXlXzXgX7XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.~ ! ! ! ! ! ! ! ! ! ! ! ! ! ! ! ^ K V.A.Z Y o.n.;XzXmXxXjXjXkXlXlXlXlXlXfX7XUXPXIXIXIXIXIXIXIXIXIXIXIXIXIXIXUXKXY.C.D.S.",
"S.A.F.n.L J K J J J J J J J J J J J J J P F t.:.1.~.yXMXmXxXlXzXxXxXxXxXxXzXlXxXxXqXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXT.C.D.S.",
"S.S.S.A.v.v.v.v.v.v.v.v.v.v.v.v.c.c.n.M.k.r.m.!.-X6X1X:X:X>X>X>X>X>X>X:X;X>X5X3X{.].qX7X7X7X7X7X7X7X7X7X7X7X6X6X9XtX0X@XG.A.S.S.",
"S.D.Z.I.mXNXNXNXNXNXNXNXNXNXMXNXZXVXjXeXuXfX XnXjXgXhXjXjXjXjXjXjXhXgXzXnXgX@Xd.@.{.xXfXgXgXgXgXgXgXgXgXfXfXlXvXiX{.9.>.G.A.S.S.",
"S.S.Z.P.hXkXjXjXjXjXjXjXhXlXxXgX9X1XqXbXUXaXXXlXlXzXzXzXzXlXlXkXlXnXmXrXQ.5.^ S s.3XxXlXzXzXzXzXzXlXkXzXmXnX9XL.>.Q F S.Q.V.S.S.",
"S.S.Z.P.kXlXlXlXlXkXlXcXcXaX6X5XdXGXUXUXHX3X,XjXlXlXlXlXkXjXxXmXzX:Xn.o.I I E ~ +X5XlXlXlXlXlXkXkXcXMXjX#Xj.} P U R { 4XR.C.S.S.",
"S.S.Z.P.kXlXlXlXlXcXkXeX2XqXvXUXUXUXPXUXhXqX2XhXzXlXlXlXbXmXpX_.q.( L Y Q ~ I 3.fX,XzXlXlXlXlXnXnXrXW.3.! L T ! ~ L f.cXL.Z.S.S.",
"S.S.Z.P.kXlXlXlXzX0X3XsXSXUXUXUXIXUXUXUX5XjX,XjXzXlXlXzX3XA.#.T P T ! Q W Q I W.nX;XxXlXlXlXlX;Xb...U P R ! Q W W W OXbXL.Z.S.S.",
"S.S.Z.P.kXlXkXvXqXwXUXVX6X7XuXUXPXIXUXMX4XnX:XjXzXkXbX2X| H  .3.4.+.T ! Q Y X.eXzX:XxXlXjXmXOX/ J #.1.5.} T Q Q I <.hXlXP.Z.S.S.",
"S.S.Z.P.kXzXlXzX2XUXUXlXNXUXyXUXUXIXUXwXuXvX>XjXlXjXmXZ.H I %.~ ~ $.J T ! L b.mXhX>XxXkXkXvXa.G Y -.U [ +.Y Q Q I Y.MXhXP.Z.S.S.",
"S.S.Z.P.kXlXcXyXuXMXpX3X2XeX*XdXdXUXGX2XzXzX>XjXlXxXiX@. .%.8.<.<.8.$.+.R / -XnXgX>XxXjXbX4X' @.%.q.;.6.X.Y ! T  .qXvXjXP.Z.S.S.",
"S.S.Z.P.kXlXcX3XSXwXZXfXM.c.&XUX5XPXgXqXcXzX>XjXkXMX).Y 3.~ <.P.P.<.~ 4.P 9.zXlXjX>XxXjXMXS.R 3.W w.I.K...Y ~ L x.nXkXjXP.Z.S.S.",
"S.S.Z.P.jXxXfX6XUX8XZXfXM.c.&XUX6XFX6XjXlXxX>XjXlXzX0.P 4.~ <.P.P.<.~ 3.T ).MXkXjX>XzXzXaX%.Q 3.W w.I.K...T W ~ &XnXkXkXP.Z.S.S.",
"S.S.Z.P.jXbX8XkXUXxXaX3X2XeX*XsXjXvX6XvXkXxX>XgXnX-X^ R +.$.8.<.<.8.%. .@.iXxXlXjX>XlXmX'.T Q $.$.q.;.6.X.R I 7.kXlXlXkXP.Z.S.S.",
"S.S.Z.P.kXlX3XLXUXUXUXxXNXUXtXUXUX0XaXxXkXxX>XgXmXb.L ! T J $.~ ~ %.I H Z.mXjXlXjX>XzXzXw.P ! T L =.U [ @.R U ^.MXjXzXkXP.Z.S.S.",
"S.S.Z.P.xXtXiXUXIXPXUXnX2X9XfXUXlX2XcXkXlXxX:XzXeXX.Y Q ! T +.4.3. .H | 2XbXkXzXjX:XmX:X( E Q ! R *.2.4.` F =.yXcXkXlXkXP.Z.S.S.",
"S.S.Z.P.xX3XAXUXIXIXIXUXUXKXxX7X3XhXzXlXlXxX;XnXW.I Q W Q ! R P Y @.V.2XzXlXlXzXjX:XMXM.L ! W Q ! T P R =.H.9XxXkXlXlXkXP.Z.S.S.",
"S.S.Z.U.pX0XUXPXUXUXUXZXuX3X8XfXvXzXlXlXlXzX,XfX3.I ~ Q T L / 8./.iXmXbXlXlXlXzXhX1XyXO.T ~ Q Y L ` y.}.dXMXvXkXlXlXlXkXP.Z.S.S.",
"S.S.C.R.4XcXUXUXIXcX9X3XtXlXvXzXkXlXlXlXlXlX5X+X~ E I I ..c.=XlXMXxXjXkXlXlXlXzXgX6X/.Y W P Y #.C.1XcXmXzXjXkXlXlXlXlXkXP.Z.S.S.",
"S.S.A.J.4XUXAXpX2X4XpXzXzXjXhXjXjXjXjXjXhXkX2Xs.S ~ 3.R.wXmXnXzXkXlXlXzXzXzXzXlXjX:X5.D ( q.(.iXMXnXlXkXlXzXzXzXzXzXzXlXP.Z.S.S.",
"S.S.S.Z.eXjX0XsXMXZXVXMXMXNXNXNXNXNXNXNXmXSX.XO.a.oXfXnXzXhXgXjXjXjXjXjXjXhXjXlXmXT...l.%XhXvXjXdXfXgXgXgXgXgXgXgXgXhXfXP.Z.S.S.",
"S.S.D.Z.u.d.n.m.v.c.v.v.v.v.v.v.v.v.v.v.v.x.D..X2X5X,X;X:X>X>X>X>X>X>X:X,X2X,XoX'.~.-XrXrX7X6X7X7X7X7X7X7X7X7X7X7X7X8X6XK.Z.S.S.",
"S.A.F.n.U L J J J J J J J J J J J J J J P B x.SXkXlXzXxXxXxXxXxXzXzXvXnXjXqX3XfX9X-XUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXY.C.D.S.",
"S.S.F.m.~ Q ! ! ! ! ! ! ! ! ! ! ! ! ! ! ^ P v.mXhXlXlXlXlXkXkXlXcXxXiX4X5XgXHXUX5X2XUXPXIXIXIXIXIXIXIXIXIXIXIXIXIXIXUXLXY.C.D.S.",
"S.S.F.m.Q W W W W W W W W W W W W W W W ! J v.NXjXlXlXlXkXxXvXjXwX2XwXmXUXUXUXNX<XqXUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.Q W W W W W W W E R W W W W W W ! J v.NXjXlXlXzXcXaX6X5XgXFXUXUXUXPXUXrXeX0XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.Q W W W W W W W / ( Q W W W W W ! J v.NXjXlXzXhX3X0XvXFXPXUXIXIXUXUXGX3XjX7XUXIXUXUXUXUXUXIXFXHXUXUXUXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.Q W W W W Q T ..4.>.;.T ! W W W ! J v.NXjXkXvX4XlXUXjX6X5XdXUXPXIXUXfXwXlX7XUXIXUXUXUXPXUXeX0X2XvXUXIXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.Q W W W W R L X.` K =.I T W W W ! J v.NXjXzXfX6XUXUXsXUXUXdXUXUXUXUX5XjXhX7XUXIXUXUXUXUXUXyXUXZXjXUXIXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.Q W W Q T @.;.6.t.9.t.=.;.Q W W ! J v.NXhXvX8XzXfXtX*X&X&X*XyXuXUXbX5XbXfX7XUXIXUXUXIXeXyX@X:XOXzXUXIXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.Q W W Q T ,.Q ..K.Y.9.K >.( R W ! J v.NXjXlX3XJX9XUXeXc.c.eXUX7XUXqXpXcXgX7XUXIXUXUXFX0XUX;Xz.m.xXUXIXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.Q W W Q T <...-.G.K.t.` 4./ E W ! J v.MXzXtXuXUX2XNX2XM.M.2XNX6XDX3XxXlXgX7XUXIXUXUXHX2XZX@Xm.B.xXUXIXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.Q W W W E ] X.<.-...6.X...W W W ! J v.MXzX3XCXUXnXxX3XfXfX3XlXVXsXwXcXlXgX7XUXIXUXUXUXcXzX,XxXrXlXUXIXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.Q W W W W E K X...Q ;.L T W W W ! J v.VXpX8XUXIXUXUXaXZXZXpXUXUX2XkXlXzXgX7XUXIXUXUXUXUXUXrXPXcXhXUXIXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.Q W W W W Q E ] <.,.@.R Q W W W ! J c.ZX5XcXUXIXPXUXxX8XwXMXUXwX9XvXkXzXgX7XUXIXUXUXUXPXUXgX0X8XVXUXIXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.Q W W W W W W E T T T W W W W W ! J v.MX2XIXUXUXIXUXUXUXSXiX1XqXzXlXlXzXgX7XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.Q W W W W W W W Q Q Q W W W W W ! J m.sXiXUXPXUXUXPXlX7X2XtXzXvXlXlXlXzXgX7XUXIXUXUXUXUXUXIXIXIXUXUXUXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.! W W W W W W W W W W W W W W W ! J n.0XAXUXUXAXiX3X8XdXcXcXlXkXlXlXlXzXgX7XUXIXUXUXUXUXUXUXUXUXUXUXUXUXUXIXUXPXY.C.D.S.",
"S.S.F.m.Q E W W W W W W W W W W W W W W Q L d.hXUXvX0X3XrXlXvXxXlXlXzXlXlXlXlXzXhX8XUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXUXIXY.C.D.S.",
"S.S.F.m.~ Q ! Q Q Q Q Q Q Q Q Q Q Q Q Q ~ U u.eX5X3XpXxXxXkXjXjXkXkXkXkXkXkXkXlXfX6XUXLXPXPXPXPXPXPXPXPXPXPXPXPXPXPXIXKXY.C.D.S.",
"S.S.S.A.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.m.n.Z.Z.J.R.U.P.P.P.P.P.P.P.P.P.P.P.P.P.P.K.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.D.S.S.S.",
"S.S.S.S.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.F.D.S.A.C.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.C.S.S.S.S.",
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.A.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.D.S.S.S.S.",
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S."
};

/* XPM */
static const char *const xpm_icon_4[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.",
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.A.S.D.S.S.S.S.S.S.S.S.S.S.S.S.D.D.D.D.D.D.D.D.D.D.D.D.D.S.S.S.S.",
"S.S.S.S.F.F.F.F.F.F.F.F.F.F.F.F.F.A.Z.Z.Z.Z.Z.Z.Z.Z.Z.C.V.C.S.C.C.C.C.C.C.C.C.C.C.C.C.C.S.S.S.S.",
"S.S.S.A.m.n.m.m.m.m.m.m.m.m.m.m.n.H.I.P.P.P.P.P.P.L.K.I.!.T.S.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.D.S.S.S.",
"S.S.F.m.^ Q ! ! ! ! ! ! ! ! ! ~ Y oXnXgXjXjXjXgXgXxXmXfX X6.S.UXLXLXPXPXPXPXPXPXPXLXPXJXY.C.D.S.",
"S.S.F.n.Q E W E E W W W E E W Q I OXNXkXzXkXzXMXNXqXL.=.P / =XIXUXUXUXUXUXUXUXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.! W W W W E T E W W W Q U oXMXjXkXMXlX+Xs.` K Y K z.aXGXUXUXUXIXUXUXUXIXUXIXUXLXY.C.D.S.",
"S.S.F.m.! E W W W (  .) W W W Q I OXMXjXxX(.,.] ^ E ~ ! R *XpXGXUXUXIXUXDXcXFXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.! E W W I O.| +.U E W Q I OXmXcX2XP R +.@.) T I 1.cXwXHXUXIXUXUXhXbXhXUXIXUXUXPXY.C.D.S.",
"S.S.F.m.! W E ( O.2.3.3.O.) E Q I OXnXmXM.) :.5.4.*...K Q.VX0XJXUXUXSXjX5X2XpXUXIXUXUXPXY.C.D.S.",
"S.S.F.m.! W T  .| 3.'.7.{ X.T ! I oXBXuXo.#.' K.K.' #. .yXbXqXJXUXUXzXmX>X0.5XUXPXUXUXPXY.C.D.S.",
"S.S.F.m.! W E ) +.3.7.3.+._ E Q I .XFX~.L o.*.8.8.;.` b.NXlXwXJXUXUXAXhX4X;XiXUXIXUXUXPXY.C.D.S.",
"S.S.F.m.! E W W U O.{ +.U E W Q I oXBX2.P T _ +.O.Q L ,XbXzXwXJXUXIXUXUXhXmXhXUXIXUXUXPXY.C.D.S.",
"S.S.F.m.! E W W E ) X._ E Q W Q P &X3XR Q ~ W ) ] %.R.zXkXxXwXJXUXUXIXUXAXzXDXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.! W W W W E T E W W W Q P =XB.J R K ^ q.[.gXMXlXkXxXwXHXUXUXUXIXUXUXUXIXUXUXUXLXY.C.D.S.",
"S.S.F.m.~ Q Q Q Q Q ! Q Q Q Q Q E /.| J @.C.4XmXBXxXlXzXzXxXwXKXUXUXUXUXUXUXUXUXUXUXUXLXY.C.D.S.",
"S.A.F.n.Y I U I I I I I I I Y Y W r.<.Q.rXcXlXsXsXdXdXaXdXvXrXAXKXHXJXJXJXJXJXHXGXGXIXUXY.C.D.S.",
"S.S.A.H.oXOXoXOXOXoXoXoX@X@X|.).T.`.eXuX0X6X7X8X7X7XqXiX0XE.G.rXwXwXwXwXwXqX0XwXpXaX-XS.S.S.S.S.",
"S.D.Z.I.nXNXMXMXMXNXVXNXlXaXfXKXfX5XMXlXxXxXzXxXNXVXpX~.3.Q R.vXxXxXxXzXlXvXVXvX=Xx.( 5.T.C.S.S.",
"S.S.Z.P.gXkXjXkXzXfXeX9XdXZXUXUX5X8XxXkXkXzXMXcX:Xv.} P D 2.0XdXzXkXkXbXNXuX~.2.E K P |.!.V.S.S.",
"S.S.Z.P.jXlXzXhXqXyXcXPXUXUXUXvX0XqXxXkXxXsX_.8.Q J T ^ P !.iXaXzXlXzX<Xn...K P Q T *.dXI.C.S.S.",
"S.S.Z.P.jXzXlX0XFXmXdXcXUXIXUXyXaX9XxXzXsX;.P X.%./ W T } iXqXdXkXMXE.L ` #.o.E ~ K K.MXK.Z.S.S.",
"S.S.Z.P.jXcXiXgXIXyXCXuXSXUXCXeXhX8XzXMX).P +.O.X.o./ J c.VX7XdXxXhX&.W ;.] @.R E ` 0XxXL.Z.S.S.",
"S.S.Z.P.jXxXtXkXlX2Xm.>XkXNXgXdXgX8XxXcX7.X.O.M.M.X.%.W ;XNX7XsXBX{.] O.8.K.,.T L d.MXhXP.Z.S.S.",
"S.S.Z.P.kXfXdXVXjX2Xm.>XzXkXtXxXdX7XNX;XQ %.X.M.M.O.X.7.xXxX8XsXMXw.) +.7.K.,.U E @XMXgXP.Z.S.S.",
"S.S.Z.P.zXeXNXUXDXuXCXyXPXkXuXvXdX7XVXc.J / o.X.O.@.P ).MXzX7XlX5X^ W _ *.] %.H >.lXzXjXP.Z.S.S.",
"S.S.Z.I.hXrXUXIXUXbXdXbXHX0XlXxXdXqXiX} T E / %.X.P -.sXzXxX6XvXA.K ~ T o.#._ U (.MXkXjXP.Z.S.S.",
"S.S.Z.Y.tXlXUXUXUXIXbXuX0XgXzXzXaXiX!.P ^ T J W 6.(.aXxXkXxX0XtX#.R Q P L X.m.1XxXkXzXjXP.Z.S.S.",
"S.S.Z.U.8XLXUXSXfX0XwXdXzXkXjXkXsX0X2.D L { x.-XxXNXzXkXkXlXuX^.K L E 3.^.iXNXbXkXkXlXjXP.Z.S.S.",
"S.S.A.F.jXLXhXpXkXMXVXNXMXMXMXMXVXE.W 1.Q.uXVXNXxXzXxXxXxXMXeX=._ c.-XvXVXvXlXzXxXxXcXlXI.Z.S.S.",
"S.S.S.A.Q.(.}.@X@XoXoXoXOXOXoXoX+XA.E.9XiXwX7X7X8X8X9XqX9X4X{.Z.:XaXpXwX0XqXwXwXwXwXeXqXL.Z.S.S.",
"S.S.F.m.T Y Y I I I I I I I U Y G +XVXsXaXdXdXdXgXhXaX0X6XyX%XUXIXGXGXHXJXJXJXJXJXHXJXFXY.C.D.S.",
"S.S.F.m.~ W Q Q Q Q ! Q Q Q Q ! Y oXMXkXzXzXvXxXdXrXyXcXUXSX,XLXUXUXUXUXUXUXUXUXUXUXUXIXY.C.D.S.",
"S.S.F.m.! W W W W E T E W W W Q U oXMXjXzXlXuXtXgXVXUXUXUXuX8XJXUXUXUXIXUXUXUXIXUXUXUXLXY.C.D.S.",
"S.S.F.m.! E W W E ) X._ E Q W Q I OXMXkXgX0XkXkXNXUXIXUXSXeXtXHXUXUXIXUXAXzXDXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.! E W W U O.{ +.U E W Q I OXMXzXqXHXPXzXkXSXUXUXfXsXrXHXUXIXUXUXhXmXhXUXIXUXUXPXY.C.D.S.",
"S.S.F.m.! W E ) +.3.7.3.+._ E Q I oXNXdXuXbXyX>X>XuXcXIXqXcXwXJXUXUXAXhX4X;XiXUXIXUXUXPXY.C.D.S.",
"S.S.F.m.! W T  .| 3.'.7.{ X.T ! I oXVXeXbXdXCXm.m.CXdXvXrXbXwXJXUXUXzXmX>X0.5XUXPXUXUXPXY.C.D.S.",
"S.S.F.m.! W E ( O.2.3.3.O.) E Q I oXMX0XIXbXuX2X2XyXmXyXgXcXwXJXUXUXSXjX5X2XpXUXIXUXUXPXY.C.D.S.",
"S.S.F.m.! E W W I O.| +.U E W Q I @XkXfXUXUXDXjXlXIXFXqXcXzXwXJXUXIXUXUXhXbXhXUXIXUXUXPXY.C.D.S.",
"S.S.F.m.! E W W W (  .) W W W Q I @XpXAXUXIXUXVXlXhX9XhXlXxXwXJXUXUXIXUXDXcXFXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.! W W W W E T E W W W Q Y |.gXUXUXUXBXdXrXiXlXzXkXxXwXHXUXUXUXIXUXUXUXIXUXIXUXLXY.C.D.S.",
"S.S.F.n.Q E W E E W W W E E W W Y (.KXLXzXrXeXfXxXcXzXlXlXcXeXJXUXUXUXUXUXUXUXUXUXUXUXPXY.C.D.S.",
"S.S.F.m.^ Q ! ! ! ! ! ! ! ! ! ~ T W.jX8XtXhXzXkXjXjXjXjXjXlXqXFXIXLXPXPXPXPXPXPXPXLXPXJXY.C.D.S.",
"S.S.S.A.m.n.m.m.m.m.m.m.m.m.m.m.m.A.F.U.Y.I.P.P.P.P.P.P.P.I.L.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.D.S.S.S.",
"S.S.S.S.F.F.F.F.F.F.F.F.F.F.F.F.F.S.A.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.C.C.C.C.C.C.C.C.C.C.C.C.C.S.S.S.S.",
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.D.D.D.D.D.D.D.D.D.D.D.D.D.S.S.S.S.",
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S."
};

/* XPM */
static const char *const xpm_icon_5[] = {
/* columns rows colors chars-per-pixel */
"44 44 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.",
"S.S.S.S.A.A.A.A.A.A.A.A.A.A.A.S.D.D.D.D.D.D.D.D.D.D.D.S.D.D.D.D.D.D.D.D.D.D.D.D.S.S.S.S.",
"S.S.S.D.H.H.H.H.H.H.H.H.H.H.H.F.V.V.V.V.V.V.V.V.V.N.V.D.V.B.B.B.B.B.B.B.B.B.B.V.S.S.S.S.",
"S.S.D.V.j.j.j.j.j.j.j.j.j.k.h.b.!.!.!.!.!.!.Q.W.~.]./.C.^._.).).).).).).).)._./.D.S.S.S.",
"S.A.H.j.U R R R R R R R R E J >.bXxXxXxXzXzXmXCXhX|.5.s.PXUXUXUXUXUXUXUXUXUXUXGXH.A.S.S.",
"S.A.H.j.R Q Q W Q W Q W W ! I <.xXkXkXlXMXnX6XS.@.L P |.GXUXIXIXIXIXIXIXIXIXUXSXH.A.S.S.",
"S.A.H.j.R Q W Q W Q W Q W ! P ,.cXkXzXjXoXi.( K T I 8.pXVXUXIXIXUXUXUXUXUXIXUXSXH.A.S.S.",
"S.A.H.j.R W Q Y ( #...Y W ! P ,.cXkXxXr.P } X.W ! L ).hXBXUXIXUXUXhXhXKXUXIXUXSXH.A.S.S.",
"S.A.H.j.R Q W ( $.+.*.{ ! Q P ,.zXnX=XQ @.%.*...E ..dXuXVXUXUXJXlXaXfXFXUXIXUXSXH.A.S.S.",
"S.A.H.j.R W Q #.+.T.i...} E I ,.zXNXj.} O.J.z.X.` b.ZXeXCXUXUXhXbXK.H.UXUXIXUXSXH.A.S.S.",
"S.A.H.j.R Q W ..*.i.6.O._ W P >.nXrX' { %.y.q.@.} ,XNXrXCXUXUXMXgX$X&XKXUXIXUXSXH.A.S.S.",
"S.A.H.j.R W Q Y { ..O.E E ! P :.CXY.K E ' O.o.S 8.bXzXtXCXUXIXUXGXlXlXFXUXIXUXSXH.A.S.S.",
"S.A.H.j.R W W W ! } _ E W ! P <.xX:.Y ~ U ^ o.a.5XcXxXtXCXUXIXUXUXBXNXUXUXIXUXSXH.A.S.S.",
"S.A.H.k.E ! ! ! Q E W ! ! ~ P 8.%XI K I %.F.7XMXcXjXxXrXVXUXPXIXIXUXUXIXIXPXUXAXH.A.S.S.",
"S.A.H.h.J I P P P I P P P I D 2.y.T p.XXlXZXmXzXzXzXvXaXDXUXUXUXUXUXUXUXUXUXUXKXH.A.S.S.",
"S.S.F.b.>.<.,.,.,.,.,.,.2.2.%.8.M.oXiXaXwX9X0X9XqXiXsX-XiXcXlXzXzXzXlXkXkXnXVXtXD.S.S.S.",
"S.D.V.!.bXxXcXcXxXvXbXxXdXtXkX;XgXlXaXpXaXpXfXcXgX$Xt.y.uXsXpXaXpXiXsXlXhX-Xf.6.J.A.S.S.",
"S.D.V.!.xXkXkXzXxXfXrXrXkXJXHX,XfXxXzXzXmXCXdX).6.Q K (.kXcXxXzXnXCXkX Xr.( D L.R.C.S.S.",
"S.D.V.!.xXkXzXsXrXsXBXIXUXUXgX5XfXzXlXvX2XM. .L I P 2.tXiXxXkXvX9XD.@.P P U O.qXJ.Z.S.S.",
"S.D.V.!.xXzXaXdXCXhXMXUXUXHXyXeXsXzXcXx.W { } W ~ K E.gXtXzXnXH.Q ] | ~ ^ J M.xXD.A.S.S.",
"S.D.V.!.xXzXeXGXlXzXaXCXUXxXsXrXaXmX1XW  .@.$.{ R ] uXiXyXbXtX[ ` %.+.) R Q 1XkXF.A.S.S.",
"S.D.V.!.vXdXdXkXsXN.+XzXMXpXzXwXpXCXm.{ @.A.j.o.) h.CXeXtXZXY.[ O.n.n.! L 9.nXaXG.A.S.S.",
"S.D.V.Q.bXeXCXxXiX~.*XxXhXuXbX0XfXsX| } $.j.u.@.{ &XBXeXiXvX;.` @.s.s./ P '.VXpXG.A.S.S.",
"S.D.V.!.zXyXUXUXcXvXkXUXaXfXvX9XcX(.L W { o.@.K <.cXxXeXhX&XT E ` +.O.U  .fXcXaXG.A.S.S.",
"S.D.V.^.pXcXUXUXUXcXlXgXtXzXxXqXgX6.I ~ R ) { ,.*XbXzXeXhXh.L ^ R ( [ =.}.bXlXsXG.A.S.S.",
"S.D.V.~.rXLXUXLXnXsXtXaXzXjXlXiX#XQ P K ] g.%XcXvXjXzXiX1X[ L K ( u..XkXnXjXzXaXG.A.S.S.",
"S.D.Z.U.nXUXzXiXaXlXnXnXvXcXbXdXt.K 1.R.yXCXBXxXzXxXvXkXv.H =.J.qXBXVXcXzXxXvXfXG.A.S.S.",
"S.S.A.H.>X:X2XqXeXqX0XqXqX0XtX&Xy./.tXgXiXeXeXrXyXuXtX<Xa.Y.wXhXaXrXrXtXtXtXuX9XF.A.S.S.",
"S.A.G.l.! ` ` ) ( ) ) ) ) _ W 2.kXhXiXtXyXiXaXaXeX3X0X#XvXIXZXBXVXCXCXCXCXVXAXvXG.A.S.S.",
"S.A.H.j.Y R R R R E E R R W K ,.vXlXxXcXbXzXsXyXfXZXUX5XAXUXUXUXUXUXUXUXUXUXUXGXH.A.S.S.",
"S.A.H.j.R Q Q Q W R R Q Q ! I <.xXkXlXjXtXiXxXFXUXUXbX4XAXUXIXIXUXUXUXUXIXIXUXSXH.A.S.S.",
"S.A.H.j.R W W R ^ +.{ R W ! P ,.cXlXhXtXmXjXNXUXIXUXiXrXCXUXIXUXUXxXzXIXUXIXUXSXH.A.S.S.",
"S.A.H.j.R Q W W o.| @./ W ! P ,.xXxXrXZXCXxXgXZXUXVXuXiXVXUXUXUXBXkXzXDXUXIXUXSXH.A.S.S.",
"S.A.H.j.R Q W +.%.B.e.o.[ E I ,.cXhXiXlXgXT.}.kXNXgXhXuXCXUXUXxXkX(.(.IXUXIXUXSXH.A.S.S.",
"S.A.H.j.R Q W +.$.C.r.o.[ E I ,.bXyXnXcXgXY.{.zXjXuXvXtXCXUXUXzXlX^.^.IXUXIXUXSXH.A.S.S.",
"S.A.H.j.R Q W W o. .#.( W ! P ,.vXeXKXUXcXzXhXKXlXiXbXtXCXUXUXUXNXkXzXDXUXIXUXSXH.A.S.S.",
"S.A.H.j.R W W R ^ +.{ T W ! P 1.gXfXUXUXUXcXzXnXeXlXcXtXCXUXIXUXUXzXlXPXUXIXUXSXH.A.S.S.",
"S.A.H.j.R Q W Q W R R Q W ! P 2.tXAXUXUXSXlXyXyXkXkXxXtXVXUXIXIXIXUXUXUXIXIXUXSXH.A.S.S.",
"S.A.H.j.Y E R R R E E R R W L -.hXUXMXaXtXdXxXvXxXzXbXuXAXUXUXUXUXUXUXUXUXUXUXGXH.A.S.S.",
"S.A.G.l./ _ ) ) ) ) ) ) ) _ ~ ;.9X9X8XiXfXdXsXaXsXaXfX9XvXGXSXSXSXSXSXSXSXSXGXmXH.A.S.S.",
"S.S.S.A.C.C.C.C.C.C.C.C.C.C.C.Z.Z.F.K.H.F.G.G.G.G.G.G.F.G.H.H.H.H.H.H.H.H.H.H.H.S.S.S.S.",
"S.S.S.S.D.D.D.D.D.D.D.D.D.D.D.D.S.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.A.S.S.S.S.",
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.",
"S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S.S."
};

/* XPM */
static const char *const xpm_icon_6[] = {
/* columns rows colors chars-per-pixel */
"32 32 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"S.S.F.F.F.F.F.F.F.F.F.A.Z.Z.Z.Z.Z.Z.V.C.S.Z.Z.Z.Z.Z.Z.Z.Z.Z.S.S.",
"S.A.M.M.M.M.M.M.M.M.M.G.P.L.L.K.J.K.W.E.D.I.I.I.I.I.I.I.I.I.D.S.",
"F.M.( ! ~ ~ ^ ~ ~ / Y |.bXfXfXlXmXkX$X0.J.UXJXKXKXJXKXKXLXFXI.Z.",
"F.M.! R W E T E W Q L .XBXlXVXuXW.1.U W 2XUXUXUXUXUXUXUXUXLXI.Z.",
"F.M.~ W E Q { ~ R ! P  XNXdXb.+.W P K k.zXJXUXUXKXmXKXUXUXKXI.Z.",
"F.M.~ E Q  .=.o.! Q P }.GX`.L #.=.' T *XjXJXUXLXkXyXZXUXUXKXI.Z.",
"F.M.^ T { =.D.1.| W P |.ZXq.{ z.z.{ 4.xXpXKXUXbX7XC.CXUXUXKXI.Z.",
"F.M.~ E ~ o.1.#.^ Q L @X8XE ] <.>.U Q.VXuXLXUXHXfX7XZXUXUXKXI.Z.",
"F.M.~ W R ! | ^ R ! K *XD.J Y Q ] q.aXxXpXLXUXUXHXbXJXUXUXKXI.Z.",
"F.M./ Q ! Q W Q ! ! T )...D ..n.<XmXxXkXpXPXUXUXUXUXUXUXUXJXI.Z.",
"F.M.Y L P P P P P I Y q.:.E.tXmXxXsXfXbXdXHXPXLXLXKXJXJXUXUXI.C.",
"A.G.|..X X XXXXX}._.!.'.iXgXtX0XtXgXpX(.U.dXpXpXuXpXjXzX3XK.S.S.",
"Z.P.bXBXBXNXvXkXcXIXmXeXbXjXmXVXaX/.3.T /.bXkXxXVXcX*Xk.Q 0.E.C.",
"Z.L.fXlXsXyXsXAXUXUXrXeXlXxX1XM...K S 2.iXfXxXaX!.5.T J U $XW.V.",
"Z.L.jXjXgXAXcXCXUXBXtXtXmX1X! ( } / K ^.gXsXmXq.U { ` I 1.kXK.Z.",
"Z.K.jXsXkXfX/.qXCXjXsXwXVXm.( a.u.} ..pXtXxX1X] >.z.[ G Q.mXJ.Z.",
"Z.L.gXfXCXpX/.rXcXaXhXyXpX..} u.a.( m.VX0XmXn.Q <.x._ ` pXkXK.Z.",
"Z.P.iXvXUXSXcXCXlXfXgXgX^.K / } ( ! <XmXtXyX..Y ] [ K n.BXfXL.Z.",
"Z.P.eXKXUXGXgXyXpXlXdXiX2.D K  .n.<XxXjXgX!.G K W w.'.gXxXgXL.Z.",
"A.G.cXUXbXkXcXNXBXMXAX).Y 2.~.pXVXmXlXnXuX#._ m.<XbXBXzXzXjXL.Z.",
"S.A.~._.[.XXXX X X XoXF.).iXgXyXwXtXeXwXXXK.0XzXhXiXuXpXaXyXK.Z.",
"F.M.Y P I P P P P I S oXAXdXgXhXdXyXyXkX6XUXUXJXKXKXLXLXPXGXI.Z.",
"F.M.^ W ! Q W Q ! ~ I  XMXlXgXaXjXBXUXDXqXPXUXUXUXUXUXUXUXLXI.Z.",
"F.M.~ W R ! | ^ R ! P  XBXpXlXcXCXUXUXfXyXPXUXUXHXbXJXUXUXKXI.Z.",
"F.M.~ E ~ o.1.#.^ Q P  XNXyXCXtXqXCXDXiXsXLXUXHXfX7XZXUXUXKXI.Z.",
"F.M.^ T { =.D.1.| W P XXcXgXcX/./.cXfXgXaXKXUXbX7XC.CXUXUXKXI.Z.",
"F.M.~ E Q  .=.o.! Q P XXjXFXSXpXfXAXiXzXpXLXUXLXkXyXZXUXUXKXI.Z.",
"F.M.~ W E Q { ~ R ! I [.bXUXUXCXkXgXdXxXpXLXUXUXKXmXKXUXUXKXI.Z.",
"F.M.! R W E T E W W P _.UXLXvXfXsXjXxXzXaXPXUXUXUXUXUXUXUXLXI.Z.",
"F.M.( ! ~ ~ ^ ~ ~ ^ Y ~.cXeXiXgXjXjXgXjXyXGXLXKXKXJXKXKXLXFXI.Z.",
"S.A.M.M.M.M.M.M.M.M.M.A.G.P.P.L.K.L.L.L.K.I.I.I.I.I.I.I.I.I.D.S.",
"S.S.F.F.F.F.F.F.F.F.F.S.A.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.Z.S.S."
};

/* XPM */
static const char *const xpm_icon_7[] = {
/* columns rows colors chars-per-pixel */
"24 24 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"A.n.b.b.b.b.b.b.J.Y.I.L.U./.W.D.E.R.R.R.R.R.Y.S.",
"n.( ! ~ ! ~ ^ R #XvXjXmXgXXX4.(.UXHXKXLXJXIXMXG.",
"b.! R E ! E W I $XVXrXP.=.H ` iXUXUXUXPXUXUXZXG.",
"b.~ E _ %.' W U $XBX,./  .K Z.mXLXUXmXdXLXUXVXG.",
"b.! ! %.z.-.^ L ,X:X/ h.y.] 3XzXUXGX5X'.UXUXVXG.",
"b.~ E ' -.] Q P <Xx.P #.! t.mXdXUXUXbXiXLXUXVXG.",
"b.^ W W ^ Q W W _.( H *.J.yXzXfXUXUXUXKXUXUXVXG.",
"b.R I U I Y U E 0.5.[.sXbXlXbXhXKXLXKXKXJXUXFXF.",
"J.#X%X&X%X+XoX}.+XjXhXfXjXyXU.!.lXaXfXcXzX&XZ.F.",
"Y.vXNXcXxXNXUXNXiXcXbXqXH.#.R $XvXvXhX].q.K l.R.",
"I.gXdXlXvXPXUXyXtXmXV.' W Z p.gXcX*X+./ K ) 3XL.",
"U.gXfXlX XfXMXiXfXqX' 8.w.! oXgXvXu...f.P d.kXS.",
"Y.pXNXcX&XzXgXsXzXG.W w.#.=.lXdX4X) ;.8.G %XjXS.",
"U.yXUXUXvXhXdXgXyX#.Z ! *.|.vXjXA.C U  .M.cXiXF.",
"K.NXUXMXvXnXBXDXT.T i.oXlXmXbX8X' $.Y.rXmXxXuXF.",
"A.I.T.W.^.~.!.~.L.&XhXjXiXwXrXXX[.jXmXkXdXjXtXF.",
"v.I J K H J K A =XZXfXdXaXhXnXiXUXUXPXUXIXUXCXG.",
"b./ Q ! _ ! ~ T $XnXdXjXAXUXVXiXIXUXIXGXIXUXVXG.",
"b.~ E { 2.| Q U &XxXxXiXpXLXfXfXUXIXkX9XPXUXVXG.",
"b.~ Q %.k.=.^ I $XcXnX X;XvXsXhXUXHX6X[.UXUXVXG.",
"b.^ E ( O.) W T oXCXUXbXbXjXgXgXIXUXCXlXLXUXVXG.",
"b.Q T T R T R P OXUXJXvXfXlXcXjXUXUXUXUXUXUXAXG.",
"m.{ ` ] ' ' ] / ].fX9XrXpXpXuXrXCXVXVXCXVXAXlXF.",
"S.Z.Z.Z.Z.Z.Z.Z.Z.S.H.G.F.F.F.F.G.G.G.G.G.G.F.S."
};

/* XPM */
static const char *const xpm_icon_8[] = {
/* columns rows colors chars-per-pixel */
"16 16 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"A.N.N.N.M.Z.L.L.~.Y.F.U.P.I.P.D.",
"N.] ~ ( Y d.nXiX`.5.7XUXHXJXVXP.",
"N.~ / O.G g.gX7.E ,.FXUXzXPXKXI.",
"N.( O.e.P n.R.` O.[.FXJX>XAXGXP.",
"M.Y H Y V 0.%...U.lXCXUXJXUXUXU.",
"Z.f.s.p.y.l._.jXSX3X0XCXFXFX7XF.",
"L.cXBXAXUXhXNX,Xd.X.3XlX[.1.5.Y.",
"L.pXpXrXVXdX:X&.~ d.SXY.o.L _.~.",
"J.dXMX8XsXcXg.~ &.,XkX+.] 3.aXL.",
"H.MXUXMXAX0X..g.;XNXQ.[ S.wXdXJ.",
"C.p.u.s.i.V.0XcXgXiX,XvXJXZXzXL.",
"M.T J Y M i.AXdXAXCXNXUXHXUXJXI.",
"N.( O.e.Y s.MX8XuXzXbXLX>XAXHXP.",
"N.~ / O.J u.IXMXdXhXBXUXxXPXKXI.",
"N.] ~ ( T p.MXfXsXaXzXJXJXJXVXP.",
"A.N.N.N.M.C.H.J.L.K.L.I.P.I.P.D."
};

const char *const *const xpm_icons[] = {
    xpm_icon_0,
    xpm_icon_1,
    xpm_icon_2,
    xpm_icon_3,
    xpm_icon_4,
    xpm_icon_5,
    xpm_icon_6,
    xpm_icon_7,
    xpm_icon_8,
};
const int n_xpm_icons = 9;
